@@ -51,6 +51,9 @@ public class CommandThread extends AgentThread {
 
 	// ロガー
 	static private Log log = LogFactory.getLog(CommandThread.class);
+	
+	// ジョブを起こす（Runtime.execする）際にシリアル化するための専用ロックオブジェクト
+	private static final Object lockNewProcess = new Object();
 
 	/**
 	 * デバッグ用メイン処理
@@ -156,13 +159,13 @@ public class CommandThread extends AgentThread {
 				// 終了を送信
 				info.setStatus(RunStatusConstant.ERROR);
 				info.setTime(new Date());
-				info
-						.setErrorMessage("The execution user of the command and agent's user are different. ");
+				String errMsg = "The execution user of the command and agent's user are different. " +
+				"execUser=[" + m_info.getUser() + "], agentUser=[" + sysUserName + "]";
+				info.setErrorMessage(errMsg);
 				info.setMessage("");
 				m_sendQueue.put(info);
 
-				log
-						.error("The execution user of the command and agent's user are different. ");
+				log	.error(errMsg);
 				log.info("run end");
 
 				// 実行履歴削除メッセージ送信
@@ -223,7 +226,12 @@ public class CommandThread extends AgentThread {
 					log.info("Command Execute:" + cmd[i]);
 				}
 			}
-			process = runtime.exec(cmd);
+			// JVM（Windows環境）の不具合（？）でRuntime.execの並列実行多重度を上げた
+			// 場合に問題が発生することがあるため、同時にただ１つのスレッドのみがexecを実行
+			// できるように、staticなロックオブジェクトのsynchronizedによってシリアル化する
+			synchronized(lockNewProcess) {
+				process = runtime.exec(cmd);
+			}
 		} catch (IOException e) {
 			log.error(e);
 			m_errMsg = e.getMessage();
