@@ -25,6 +25,7 @@ import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.Tree;
 
 import com.clustercontrol.action.GetFacilityTree;
@@ -42,9 +43,16 @@ public class FacilityTreeComposite extends Composite {
 	
 	//	 ----- instance フィールド ----- //
 	
+
+	/** テーブルビューア */
+	private CommonTableViewer tableViewer = null;
+	
 	/** ツリービューア */
 	protected TreeViewer treeViewer = null;
 	
+	/** rootFacilityId以下のスコープ情報を取得する。 */
+	protected String rootFacilityId = null;
+	
 	/** 選択アイテム */
 	protected FacilityTreeItem selectItem = null;
 	
@@ -52,16 +60,13 @@ public class FacilityTreeComposite extends Composite {
 	protected int subScopeNumber;
 	
 	/**ノードをツリーに含めるか？ */
-	protected boolean scopeOnly = false;
+	protected boolean scopeOnly;
 	
 	/**未登録ノード　スコープをツリーに含めるか？**/
-	protected boolean unregistered = true;
+	protected boolean unregistered;
 	
 	/**内部イベント　スコープをツリーに含めるか？**/
-	protected boolean internal = true;
-	
-	/** リポジトリ情報更新により、表示をリフレッシュするかどうか **/
-	protected boolean topicRefresh = true;
+	protected boolean internal;
 	
 	protected UpdateRepositoryInfoReceiveTopic updateRepository = null;
 	
@@ -89,27 +94,18 @@ public class FacilityTreeComposite extends Composite {
 		this.createContents();
 	}
 	
-	/**
-	 * コンストラクタ
-	 * 
-	 * @param parent 親のコンポジット
-	 * @param style スタイル
-	 * @param scopeOnly スコープのみのスコープツリーとするかどうか
-	 * @param unregistered UNREGISTEREDをスコープツリーに含めるかどうか
-	 * @param internal INTERNALをスコープツリーに含めるかどうか
-	 * @param topicRefresh リポジトリ情報が更新された際に画面リフレッシュするかどうか
-	 */
+	
 	public FacilityTreeComposite(Composite parent, int style,
 			boolean scopeOnly ,
 			boolean unregistered,
-			boolean internal, 
-			boolean topicRefresh) {
+			boolean internal,
+			String rootFacilityId) {
 		super(parent, style);
 		
 		this.scopeOnly = scopeOnly;
 		this.unregistered = unregistered;
 		this.internal = internal;
-		this.topicRefresh = topicRefresh;
+		this.rootFacilityId = rootFacilityId;
 		this.createContents();
 	}
 	
@@ -199,9 +195,7 @@ public class FacilityTreeComposite extends Composite {
 		});
 		
 		//マネージャからのファシリティツリー更新
-		if (topicRefresh) {
-			this.updateRepository = new UpdateRepositoryInfoReceiveTopic(this.getDisplay(), new UpdateFacilityTreeTask(this));
-		}
+		this.updateRepository = new UpdateRepositoryInfoReceiveTopic(this.getDisplay(), new UpdateFacilityTreeTask(this));
 		
 		this.addDisposeListener(new DisposeListener(){
 			public void widgetDisposed(DisposeEvent e) {
@@ -245,7 +239,11 @@ public class FacilityTreeComposite extends Composite {
 				}else{
 					//まずい。"UNREGISTERED"スコープがない！
 				}  
-			}			
+			}
+			if (rootFacilityId != null) {
+				// rootFacilityId以外を全て消す。
+				scope.keepChild(rootFacilityId);
+			}
 			
 			this.treeViewer.setInput(treeItem);
 			FacilityTreeItem selectItem[] = treeItem.getChildren();
@@ -323,4 +321,21 @@ public class FacilityTreeComposite extends Composite {
 		}
 		
 	}
+
+	public CommonTableViewer getTableViewer() {
+		return tableViewer;
+	}
+
+	public void setTableViewer(CommonTableViewer tableViewer) {
+		this.tableViewer = tableViewer;
+	}
+	
+    /**
+     * このコンポジットが利用するテーブルを返します。
+     * 
+     * @return テーブル
+     */
+    public Table getTable() {
+        return this.tableViewer.getTable();
+    }
 }
\ No newline at end of file
