@@ -341,7 +341,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_command_info";
+			String sql = "SELECT session_id, job_id FROM cc_job_command_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -392,7 +392,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_command_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_command_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -445,7 +445,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_command_info WHERE facility_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_command_info WHERE facility_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
 			
