@@ -262,7 +262,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_info";
+			String sql = "SELECT session_id, job_id, parent_job_id FROM cc_job_relation_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -314,7 +314,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND job_id = ? AND parent_job_id = ?";
+			String sql = "SELECT session_id, job_id, parent_job_id FROM cc_job_relation_info WHERE session_id = ? AND job_id = ? AND parent_job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -368,7 +368,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND parent_job_id = ? ORDER BY job_id ASC";
+			String sql = "SELECT session_id, job_id, parent_job_id FROM cc_job_relation_info WHERE session_id = ? AND parent_job_id = ? ORDER BY job_id ASC";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
@@ -428,7 +428,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
+			sql.append("SELECT a.session_id, a.job_id, a.parent_job_id FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
 			sql.append("a.job_id = b.job_id AND ");
 			sql.append("a.session_id = ? AND ");
@@ -496,7 +496,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
+			sql.append("SELECT a.session_id, a.job_id, a.parent_job_id FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
 			sql.append("a.job_id = b.job_id AND ");
 			sql.append("a.session_id = ? AND ");
@@ -561,7 +561,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuilder sql = new StringBuilder();
-			sql.append("SELECT * FROM cc_job_relation_info as a, cc_job_session_job as b ");
+			sql.append("SELECT a.session_id, a.job_id, a.parent_job_id FROM cc_job_relation_info as a, cc_job_session_job as b ");
 			sql.append("WHERE a.session_id = b.session_id AND ");
 			sql.append("a.job_id = b.job_id AND ");
 			sql.append("a.session_id = ? AND ");
@@ -623,7 +623,7 @@ public class JobRelationInfoDAOImpl implements JobRelationInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id, parent_job_id FROM cc_job_relation_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
