@@ -255,7 +255,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst";
+			String sql = "SELECT job_id, parent_job_id FROM cc_job_relation_mst";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -306,7 +306,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ? AND parent_job_id = ?";
+			String sql = "SELECT job_id, parent_job_id FROM cc_job_relation_mst WHERE job_id = ? AND parent_job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -359,7 +359,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
+			String sql = "SELECT job_id, parent_job_id FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
@@ -414,7 +414,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ?";
+			String sql = "SELECT job_id, parent_job_id FROM cc_job_relation_mst WHERE job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -483,7 +483,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
+			String sql = "SELECT job_id FROM cc_job_relation_mst WHERE parent_job_id = ? ORDER BY job_id ASC";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);	
@@ -604,7 +604,7 @@ public class JobRelationMasterDAOImpl implements JobRelationMasterDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_relation_mst WHERE job_id = ?";
+			String sql = "SELECT parent_job_id FROM cc_job_relation_mst WHERE job_id = ?";
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
