@@ -319,7 +319,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("SELECT * FROM cc_job_session");
+			sql.append("SELECT session_id FROM cc_job_session");
 			
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
@@ -370,7 +370,7 @@ public class JobSessionDAOImpl implements JobSessionDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_session WHERE session_id = ?";
+			String sql = "SELECT session_id FROM cc_job_session WHERE session_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
