@@ -471,7 +471,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_info";
+			String sql = "SELECT session_id, job_id FROM cc_job_start_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -522,7 +522,7 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_start_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
