@@ -41,7 +41,6 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.logagent.TransferLogManager.LogThreadManageInfo;
 import com.clustercontrol.logagent.TransferLogManager.LogTransferFileInfoFacility;
-import com.clustercontrol.logagent.util.InternalLogger;
 import com.clustercontrol.logtransfer.bean.LogTransferFileInfo;
 import com.clustercontrol.logtransfer.bean.TopicConstant;
 
@@ -263,9 +262,6 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
     public void onException(JMSException arg0) {
 
     	log.error(arg0.getMessage(), arg0);
-    	
-    	// syslogにログ出力
-		InternalLogger.error("hinemos_logagent: A problem has been detected with the connection to MGR");
 
     	m_agent.reConnection();
 
