@@ -55,7 +55,7 @@ import com.clustercontrol.repository.message.UpdateRepositoryInfo;
  *     destination-type="javax.jms.Queue"
  *     
  *     transaction-type="Container"
- *     destination-jndi-name="queue/clustercontrol/Logtransfer/LogTransferFileManage"
+ *     destination-jndi-name="queue/clustercontrolLogtransferLogTransferFileManage"
  * 
  * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=AccessController"
  * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=RepositoryController"
@@ -69,8 +69,8 @@ import com.clustercontrol.repository.message.UpdateRepositoryInfo;
  *--
  * Server Runtime Specific Tags
  * If you are not using a specific runtime, you can safely remove the tags below.
- * @jonas.message-driven-destination jndi-name="queue/clustercontrol/Logtransfer/LogTransferFileManage"
- * @jboss.destination-jndi-name name="queue/clustercontrol/Logtransfer/LogTransferFileManage"
+ * @jonas.message-driven-destination jndi-name="queue/clustercontrolLogtransferLogTransferFileManage"
+ * @jboss.destination-jndi-name name="queue/clustercontrolLogtransferLogTransferFileManage"
  *
  *--
  * <!-- end-xdoclet-definition -->
@@ -219,17 +219,19 @@ public class ManageLogTransferFileBean implements javax.ejb.MessageDrivenBean, j
 		
 		try{
 			// ファシリティIDの配下全てのファシリティIDを取得
-			ArrayList facilityIdList = null;
 			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
-			if(repository.isNode(facilityId)){
-				// ノードの場合
-				facilityIdList = new ArrayList<String>();
-				facilityIdList.add(facilityId);
-			}
-			else{
-				// スコープの場合
-				facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
-			}
+			ArrayList facilityIdList = repository.getExecTargetFacilityIdList(facilityId);
+//			ArrayList facilityIdList = null;
+//			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
+//			if(repository.isNode(facilityId)){
+//				// ノードの場合
+//				facilityIdList = new ArrayList<String>();
+//				facilityIdList.add(facilityId);
+//			}
+//			else{
+//				// スコープの場合
+//				facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+//			}
 			
 			
 			// (1)削除分のファシリティIDの抽出（キャッシュにあって、更新情報にない）
