@@ -29,6 +29,7 @@ import java.util.Vector;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
+import javax.mail.AuthenticationFailedException;
 import javax.mail.Message;
 import javax.mail.MessagingException;
 import javax.mail.Session;
@@ -59,6 +60,7 @@ import com.clustercontrol.notify.mail.ejb.session.MailTemplateControllerUtil;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.util.Messages;
+import com.sun.mail.smtp.SMTPAddressFailedException;
 
 /**
  * メールを送信するクラス<BR>
@@ -291,6 +293,12 @@ public class SendMail extends InhibitAction{
 					Transport.send(mes);
 					retryFlg = false;
 				}
+				catch(AuthenticationFailedException e){
+					throw e;
+				}
+				catch (SMTPAddressFailedException e){
+					throw e;
+				}
 				catch(MessagingException me) {
 					// メール再送信フラグを挙げる
 					retryFlg = true;
@@ -422,7 +430,7 @@ public class SendMail extends InhibitAction{
 				if (mailInfo.getMailTemplateId() != null) 
 				{
 					MailTemplateInfoData mailData = MailTemplateControllerUtil.getLocalHome().create().getMailTemplateInfo(mailInfo.getMailTemplateId());
-					buf.append(substitution(mailData.getBody() + "\n", source));
+					buf.append(substitution(mailData.getBody(), source));
 				}
 				else
 				{
