@@ -48,6 +48,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     private int m_graphType;
 
+    private int m_graphForm;
+
     private RecordCollectorData m_collectorData;
 
     private List<CollectorItemInfo> m_itemInfoList;
@@ -113,11 +115,13 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param facilityTree ファシリティツリー
      * @param itemCode 収集項目コード
      * @param graphType グラフ種別
+     * @param graphForm グラフ形式
      */
     public void drawGraph(
     		FacilityTreeItem facilityTree, 
     		CollectorItemInfo itemInfo,
             int graphType, 
+            int graphForm, 
             Date startDate, 
             Date endDate) {
     	// 表示設定がまったく変更になっていない場合は再描画しない
@@ -127,7 +131,6 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     			m_graphEndTime == endDate.getTime()){
     		return;
     	}
-    	
         // 現在表示されているグラフを消去
     	m_composite.clearData();
     	
@@ -137,10 +140,10 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         }
 
         String itemCode = itemInfo.getItemCode(); // 収集項目コード
-        String deviceName = itemInfo.getDeviceName();
+        String displayName = itemInfo.getDisplayName();
 
         // 収集項目名をタイトルに設定
-        String title = CollectorItemCodeFactory.getFullItemName(itemCode, deviceName);
+        String title = CollectorItemCodeFactory.getFullItemName(itemCode, displayName);
 
 //        if (CollectorItemCodeFactory.isDeviceSupport(itemCode)) {
 //            title = title + "(" + itemInfo.getDeviceName() + ")";
@@ -148,15 +151,15 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         if (graphType == GraphProperty.TYPE1) {
             title = title + " "
-                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "スコープ代表値"
+                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "スコープ平均値"
         } else if (graphType == GraphProperty.TYPE2) {
             title = title + " "
                     + Messages
-                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "スコープ代表値詳細"
+                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "詳細(収集項目別)"
         } else if (graphType == GraphProperty.TYPE3) {
             title = title + " "
                     + Messages
-                            .getString("SUB_SCOPE_REP_VAL"); // "サブスコープ代表値"
+                            .getString("SUB_SCOPE_REP_VAL"); // "詳細(サブスコープ別)"
         }
 
 //        Date stopDate; // 収集終了時刻
@@ -172,7 +175,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         		Messages.getString("TIME"), // 横軸ラベル
         		CollectorItemCodeFactory.getMeasure(itemCode), // 縦軸ラベル
         		graphType, // グラフタイプ
-        		CollectorItemCodeFactory.isRangeFixed(itemCode), // 軸固定フラグ
+        		graphForm, // グラフ形式
+        		CollectorItemCodeFactory.isRangeFixed(itemCode, graphType, graphForm), // 軸固定フラグ
         		m_collectorData.getIntervalSec(), // インターバル
         		startDate, // グラフ表示開始時刻
         		endDate // グラフ表示終了時刻
@@ -210,13 +214,13 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         switch (graphType) {
         case GraphProperty.TYPE1:
-        	drawGraph1(itemInfo, facilityTree, startDate, endDate);
+        	drawGraph1(itemInfo, facilityTree, startDate, endDate, graphForm);
         	break;
         case GraphProperty.TYPE2:
-        	drawGraph2(itemInfo, facilityTree, startDate, endDate);
+        	drawGraph2(itemInfo, facilityTree, startDate, endDate, graphForm);
         	break;
         case GraphProperty.TYPE3:
-        	drawGraph3(itemInfo, facilityTree, startDate, endDate);
+        	drawGraph3(itemInfo, facilityTree, startDate, endDate, graphForm);
         	break;
         default:
         	break;
@@ -229,6 +233,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     	this.m_targetFacility = facilityTree;
         this.m_currentItem = itemInfo;
         this.m_graphType = graphType;
+        this.m_graphForm = graphForm;
         this.m_graphStartTime = startDate.getTime();
         this.m_graphEndTime = endDate.getTime();
     }
@@ -251,21 +256,14 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         return this.m_graphType;
     }
 
-//    /**
-//     * グラフ描画対象の収集項目IDを設定します。
-//     * 
-//     * @param itemID 収集項目ID
-//     */
-//    public void setTargetItemID(int itemID) {
-//        Iterator itr = this.m_itemInfoList.iterator();
-//
-//        while (itr.hasNext()) {
-//            CollectorItemInfo itemInfo = (CollectorItemInfo) itr.next();
-//            if (itemInfo.getCollectorItemID() == itemID) {
-//                this.m_currentItem = itemInfo;
-//            }
-//        }
-//    }
+    /**
+     * グラスの形を取得します。
+     * 
+     * @return グラフの形
+     */
+    public int getGraphForm() {
+        return this.m_graphForm;
+    }
 
     /**
      * グラフ描画対象の収集項目IDを取得します。
@@ -276,18 +274,6 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         return this.m_currentItem;
     }
 
-//    /**
-//     * グラフ描画対象のファシリティ情報を設定します。
-//     * 
-//     * @param facilityTree ファシリティツリー
-//     */
-//    public void setTargetFacility(FacilityTreeItem facilityTree) {
-//        this.m_facilityTree = facilityTree;
-//
-//        // グラフを生成します。
-//        createGraph();
-//    }
-
     /**
      * グラフ描画対象のファシリティ情報を取得します。
      * 
@@ -304,20 +290,6 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     }
 
-//    /**
-//     * Widgetが選択されたときのアクションを定義します。
-//     */
-//    public synchronized void widgetSelected(
-//            org.eclipse.swt.events.SelectionEvent e) {
-//        double lowerBound = (this.m_composite.getHorizontalBar().getSelection()) * 1000D;
-//        double upperBound = (this.m_composite.getHorizontalBar().getThumb() + this.m_composite
-//                .getHorizontalBar().getSelection()) * 1000D;
-//
-//        this.drawGraph((long) lowerBound, (long) upperBound);
-//
-//        this.m_composite.setRange(lowerBound, upperBound);
-//    }
-
     /**
      * 
      * 指定の収集項目の代表値グラフを表示します
@@ -328,7 +300,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param endDate　描画対象終了時刻
      */
     public synchronized void drawGraph1(CollectorItemInfo itemInfo,
-            FacilityTreeItem treeItem, Date startDate, Date endDate) {
+            FacilityTreeItem treeItem, Date startDate, Date endDate, int graphForm) {
     	
         // マネージャからデータを取得
         String facilityId = treeItem.getData().getFacilityId();
@@ -357,8 +329,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
             // グラフに値を設定
-            setItemData(itemInfo.getItemCode(), itemInfo
-                    .getDeviceName(), dataList);
+            setItemData(itemInfo.getItemCode(), itemInfo.getDisplayName(), dataList);
         }
     }
     
@@ -371,7 +342,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param endDate　描画対象終了時刻
      */
     public synchronized void drawGraph2(CollectorItemInfo itemInfo,
-            FacilityTreeItem treeItem, Date startDate, Date endDate) {
+            FacilityTreeItem treeItem, Date startDate, Date endDate, int graphForm) {
         // 内訳グラフ描画に必要な収集項目のリストを取得
         List<CollectorItemInfo> itemInfoList = selectItemInfo(itemInfo, this.m_itemInfoList);
 
@@ -415,11 +386,16 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             List<CollectedDataInfo> collectedDataList = dataSet.getCollectedDataList(
             		treeItem.getData().getFacilityId(), buffer);
 
-            if(addedDataList.size() == 0){
+			// 折れ線グラフと積み上げ面グラフで場合分け
+            if(graphForm == GraphProperty.FORM1) {
             	collectedDataListTotal = collectedDataList;
-            } else {
-            	// 前の項目までの合計値
-            	collectedDataListTotal = getSumData(collectedDataListTotal, collectedDataList);
+            } else if (graphForm == GraphProperty.FORM2) {
+            	if(addedDataList.size() == 0){
+            		collectedDataListTotal = collectedDataList;
+            	} else {
+            		// 前の項目までの合計値
+            		collectedDataListTotal = getSumData(collectedDataListTotal, collectedDataList);
+            	}
             }
 
            	addedDataList.add(collectedDataListTotal);
@@ -435,7 +411,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         	for (int i = 0; i < itemSize; i++) {
         		CollectorItemInfo buffer = itemInfoList.get(i);
         		List<CollectedDataInfo> collectedDataList = addedDataList.get(i);
-        		setItemData(buffer.getItemCode(), buffer.getDeviceName(), collectedDataList);
+        		setItemData(buffer.getItemCode(), buffer.getDisplayName(), collectedDataList);
         	}
         }
     }
@@ -449,7 +425,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param endDate　描画対象終了時刻
      */
     public synchronized void drawGraph3(CollectorItemInfo itemInfo,
-            FacilityTreeItem treeItem, Date startDate, Date endDate) {
+            FacilityTreeItem treeItem, Date startDate, Date endDate, int graphForm) {
         // 子スコープを設定する
         FacilityTreeItem[] children = treeItem.getChildren();
         ArrayList<String> targetFacilitys = new ArrayList<String>();
@@ -485,18 +461,30 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
 		// グラフに値を設定
 		Iterator<String> itr = targetFacilitys.iterator();
+		List<CollectedDataInfo> collectedDataListTotal = null;
 		int i = 0;
 		while (itr.hasNext()) {
 			String targetFacility = itr.next();
 			List<CollectedDataInfo> collectedDataList = 
 					dataSet.getCollectedDataList(targetFacility, itemInfo);
-			setFacilityData(i, collectedDataList, targetFacilityNames);
+			
+			// 折れ線グラフと積み上げ面グラフで場合分け
+			if (graphForm == GraphProperty.FORM1) {
+				setFacilityData(i, collectedDataList, targetFacilityNames);
+			} else if (graphForm == GraphProperty.FORM2) {
+				if (collectedDataListTotal == null) {
+					collectedDataListTotal = collectedDataList;
+				} else {
+					collectedDataListTotal = getSumData(collectedDataListTotal, collectedDataList);
+				}
+				setFacilityData(i, collectedDataListTotal, targetFacilityNames);
+			}
 			i++;
 		}
     }
 
     /**
-	 * 凡例を収集項目名として、グラフに値を設定します。（スコープ代表値グラフ、内訳グラフの場合）
+	 * 凡例を収集項目名として、グラフに値を設定します。（スコープ平均値グラフ、詳細(収集項目別)グラフの場合）
 	 * 
 	 * @param composite
 	 *            グラフを関連づけるコンポジット
@@ -505,13 +493,13 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 	 * @param data
 	 *            性能値
 	 */
-    private void setItemData(String itemCode, String deviceName, List<CollectedDataInfo> data) {
+    private void setItemData(String itemCode, String displayName, List<CollectedDataInfo> data) {
         this.m_composite.setGraphData(CollectorItemCodeFactory.getFullItemName(
-                itemCode, deviceName), data);
+                itemCode, displayName), data);
     }
 
     /**
-     * 凡例をファシリティ名として、グラフに値を設定します。（サブスコープ代表値グラフの場合）
+     * 凡例をファシリティ名として、グラフに値を設定します。（詳細(サブスコープ別)グラフの場合）
      * 
      * @param composite グラフを関連づけるコンポジット
      * @param itemCode 収集項目コード
@@ -533,8 +521,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         List<String> itemCodeList = CollectorItemCodeFactory.getSubItemCode(target
                 .getItemCode());
 
-        // デバイス名を取得
-        String deviceName = target.getDeviceName();
+        // リポジトリ表示名を取得
+        String displayName = target.getDisplayName();
 
         // 内訳表示に必要な収集項目コードの数だけループ
         Iterator<String> itrItemCodeList = itemCodeList.iterator();
@@ -546,9 +534,9 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             Iterator<CollectorItemInfo> itrItemList = itemList.iterator();
             while (itrItemList.hasNext()) {
                 CollectorItemInfo itemInfo = itrItemList.next();
-                // itemList内に収集項目コードとデバイス名が同じ要素が重複して存在しないことが前提
+                // itemList内に収集項目コードとリポジトリ表示名が同じ要素が重複して存在しないことが前提
                 if (itemInfo.getItemCode().equals(itemCode)
-                        && itemInfo.getDeviceName().equals(deviceName)) {
+                        && itemInfo.getDisplayName().equals(displayName)) {
                     buffer = itemInfo;
                 }
             }
@@ -581,8 +569,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             	CollectedDataInfo returnData = new CollectedDataInfo(
             			data1.getFacilityId(), 
             			data1.getItemCode(),
-            			data1.getDeviceName(),
-            			data1.getCollectMethod(),
+            			data1.getDisplayName(),
             			data1.getDate(), 
             			data1.getValue() + data2.getValue());
             	dataList.add(returnData);
@@ -591,105 +578,4 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
         return dataList;
     }
-
-    /**
-     * 描画済み範囲のリストに範囲を追加する。
-     * 
-     * @param dr 描画済みリストに追加する範囲
-     */
-    private void addGotTimeArea(GraphDisplayRange dr) {
-        // 初めての描画の場合
-        if (m_gotTimeArea.size() == 0) {
-            m_gotTimeArea.add(dr);
-
-            return;
-        }
-
-        Iterator<GraphDisplayRange> itr = m_gotTimeArea.iterator();
-
-        while (itr.hasNext()) {
-            GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
-
-            if (dr.getEndTime() < drBuffer.getStartTime()) {
-                // 既に描画されている範囲と重なる範囲がないため、リストに追加する
-                int index = m_gotTimeArea.indexOf(drBuffer);
-                m_gotTimeArea.add(index, dr);
-                return;
-            } else if (drBuffer.getStartTime() <= dr.getEndTime()
-                    && dr.getEndTime() <= drBuffer.getEndTime()) {
-                // 新規追加対象の範囲の終了時刻がリストの中にある既に描画済み範囲のひとつに収まる場合
-                // その描画済み範囲と統合(範囲を広げる)する
-
-                // 追加の表示範囲の分だけ表示済み範囲を広げる
-                drBuffer.setStartTime(dr.getStartTime());
-
-                return;
-            } else if (drBuffer.getStartTime() <= dr.getStartTime()
-                    && dr.getStartTime() <= drBuffer.getEndTime()) {
-                // 新規追加対象の範囲の開始時刻がリストの中にある既に描画済み範囲のひとつに収まる場合
-                // その描画済み範囲と統合(範囲を広げる)する
-
-                // 追加の表示範囲の分だけ表示済み範囲を広げる
-                drBuffer.setEndTime(dr.getEndTime());
-
-                // 次の要素の範囲を調べ終了と開始の時刻がクロスするようなら統合する。
-                if (itr.hasNext()) {
-                    GraphDisplayRange nextDrBuffer = (GraphDisplayRange) itr
-                            .next();
-                    if (nextDrBuffer.getStartTime() <= drBuffer.getEndTime()) {
-                        // 終了時刻の大きいほうを新たな終了時刻として統合
-                        drBuffer.setEndTime(Math.max(nextDrBuffer.getEndTime(),
-                                nextDrBuffer.getEndTime()));
-
-                        // 統合された側は削除する
-                        m_gotTimeArea.remove(nextDrBuffer);
-                    }
-                }
-                return;
-            }
-        }
-        m_gotTimeArea.add(dr);
-    }
-
-    /**
-     * 描画希望範囲をあたえると、描画済みリストと照合しまだ描画されていない範囲を返す。 全ての範囲が既に描画済みの場合はnullを返す。
-     * 
-     * @param dr
-     *            描画希望範囲
-     * @return まだ描画されていない範囲
-     */
-    private GraphDisplayRange getDisplayRange(GraphDisplayRange dr) {
-        // リストにまだなにも登録されていない場合
-        if (m_gotTimeArea.size() == 0) {
-            return dr;
-        }
-
-        GraphDisplayRange returnDr = new GraphDisplayRange();
-        returnDr.setStartTime(dr.getStartTime());
-        returnDr.setEndTime(dr.getEndTime());
-
-        Iterator<GraphDisplayRange> itr = m_gotTimeArea.iterator();
-
-        while (itr.hasNext()) {
-            GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
-
-            // 開始時刻の判定
-            if (drBuffer.getStartTime() <= dr.getStartTime()
-                    && dr.getStartTime() <= drBuffer.getEndTime()) {
-                returnDr.setStartTime(drBuffer.getEndTime());
-            }
-
-            // 終了時刻の判定
-            if (drBuffer.getStartTime() <= dr.getEndTime()
-                    && dr.getEndTime() <= drBuffer.getEndTime()) {
-                returnDr.setEndTime(drBuffer.getStartTime());
-            }
-        }
-
-        if (returnDr.getStartTime() >= returnDr.getEndTime()) {
-            returnDr = null;
-        }
-
-        return returnDr;
-    }
 }
\ No newline at end of file
