@@ -31,12 +31,12 @@ import org.eclipse.swt.widgets.Composite;
 import org.jnp.interfaces.NamingContext;
 import org.jnp.interfaces.NamingContextFactory;
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.bean.PollerProtocolConstant;
 import com.clustercontrol.performance.composite.RealtimeGraphComposite;
 import com.clustercontrol.performance.util.CollectorItemCodeFactory;
 import com.clustercontrol.performance.util.RealtimeCollectThread;
 import com.clustercontrol.performance.util.RealtimeCollectorInfo;
 import com.clustercontrol.performance.view.RealtimeGraphView;
-import com.clustercontrol.performance.bean.CollectMethodConstant;
 import com.clustercontrol.performance.bean.CollectedDataInfo;
 import com.clustercontrol.performance.bean.CollectorItemInfo;
 import com.clustercontrol.performance.ejb.session.CollectorController;
@@ -203,8 +203,9 @@ public class RealtimeController {
     		RealtimeCollectThread collector,
     		//checkは今では使われていないと判断。呼び出しもとは常にfalseをセット。
     		String itemCode,
-    		String deviceName,
+    		String displayName,
     		String displayType,
+    		String displayForm,
     		String facilityId,
     		boolean check,
     		RealtimeGraphComposite graphComposite) {
@@ -217,9 +218,8 @@ public class RealtimeController {
 
     		itemList.add(new CollectorItemInfo(
     				null,	// collectionID,
-    				CollectMethodConstant.SNMP,	// collectMethod
     				itemCode,	//collectorItemCode,
-    				deviceName));
+    				displayName));
     	} else if (displayType.equals("Detail")) {
     		// 内訳表示に必要な収集項目コードを取得
     		List<String> itemCodeList = CollectorItemCodeFactory.getSubItemCode(itemCode);
@@ -227,9 +227,8 @@ public class RealtimeController {
     		for (int i = 0; i < itemCodeList.size(); i++) {
     			itemList.add(new CollectorItemInfo(
     					null,	// collectionID,
-    					CollectMethodConstant.SNMP,	// collectMethod
     					itemCodeList.get(i),	//collectorItemCode,
-    					deviceName));
+    					displayName));
     		}
     	}
 
@@ -270,7 +269,7 @@ public class RealtimeController {
         					dataCollection = myBean.getRealtimeCollectedData(
         							facilityId,
         							itemCode,
-        							deviceName,
+        							displayName,
         							CollectorControllerBean.CURRENT_SCOPE);
         				} else if (displayType.equals("Detail")) {
 
@@ -280,13 +279,13 @@ public class RealtimeController {
         					dataCollection = myBean.getRealtimeCollectedData(
         							facilityId,	// サブスコープの親スコープ。 
         							itemCode,
-        							deviceName,
+        							displayName,
         							CollectorControllerBean.SUB_SCOPE);
         				}
 
 	                    if (dataCollection != null) { //nullの場合の動作ロジックを後で記述する.
 	                    	itr = dataCollection.iterator();
-	                    	isRun = collector.setDataList(itr, displayType); // 取得した情報を渡す
+	                    	isRun = collector.setDataList(itr, displayType, displayForm); // 取得した情報を渡す
 	                    }
 
                     }	//end synchronized
