@@ -34,13 +34,14 @@ import javax.naming.NamingException;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.jnp.interfaces.NamingContext;
 
-import com.clustercontrol.performanceMGR.bean.CollectedDataSet;
-import com.clustercontrol.performanceMGR.bean.CollectorLockKey;
-import com.clustercontrol.performanceMGR.bean.CollectorProperty;
-import com.clustercontrol.performanceMGR.bean.DeviceDataSet;
-import com.clustercontrol.performanceMGR.ejb.session.CollectorController;
-import com.clustercontrol.performanceMGR.ejb.session.CollectorControllerHome;
-import com.clustercontrol.performanceMGR.util.code.CollectorItemTreeItem;
+import com.clustercontrol.performance.bean.CollectedDataSet;
+import com.clustercontrol.performance.bean.CollectorItemInfo;
+import com.clustercontrol.performance.bean.CollectorLockKey;
+import com.clustercontrol.performance.bean.CollectorProperty;
+import com.clustercontrol.performance.bean.DeviceDataSet;
+import com.clustercontrol.performance.ejb.session.CollectorController;
+import com.clustercontrol.performance.ejb.session.CollectorControllerHome;
+import com.clustercontrol.performance.util.code.CollectorItemTreeItem;
 import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.util.Messages;
 
@@ -339,9 +340,11 @@ public class RecordController {
      * 
      * @return CollectedDataSet
      */
-    public CollectedDataSet getRecordCollectedData(final String collectorID,
-            final String[] facilityIDs, final int[] itemIDs,
-            final Date startDate, final Date endDate) {
+    public CollectedDataSet getRecordCollectedData(
+            final String facilityId, 
+            final CollectorItemInfo itemInfo,
+            final Date startDate, 
+            final Date endDate) {
         CollectedDataSet dataSet = null;
 
         for (int i = 0; i <= this.errorCount; i++) {
@@ -352,8 +355,124 @@ public class RecordController {
             // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
                 try {
-                    dataSet = this.bean.getRecordCollectedData(collectorID,
-                            facilityIDs, itemIDs, startDate, endDate);
+                	String[] facilityIds = new String[1];
+                	CollectorItemInfo[] itemInfos = new CollectorItemInfo[1];
+                	
+                	facilityIds[0] = facilityId;
+                	itemInfos[0] = itemInfo;
+                	
+                	// マネージャから値が格納されたデータセットを取得
+                	dataSet = this.bean.getRecordCollectedData(facilityIds, itemInfos, startDate, endDate);
+                    return dataSet;
+                } catch (RemoteException e) {
+                    removeBean();
+                }
+            }
+        }
+
+        return null;
+    }
+    
+    /**
+     * 収集した性能値を取得します。
+     * 
+     * @return CollectedDataSet
+     */
+    public CollectedDataSet getRecordCollectedData(
+            final String facilityId, 
+            final List<CollectorItemInfo> itemInfoList,
+            final Date startDate, 
+            final Date endDate) {
+        CollectedDataSet dataSet = null;
+
+        for (int i = 0; i <= this.errorCount; i++) {
+            if (bean == null) {
+                createBean();
+            }
+
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
+            if (bean != null) {
+                try {
+                	String[] facilityIds = new String[1];
+                	facilityIds[0] = facilityId;
+
+                	CollectorItemInfo[] itemInfos = 
+                		itemInfoList.toArray(new CollectorItemInfo[itemInfoList.size()]);
+                	
+                	// マネージャから値が格納されたデータセットを取得
+                	dataSet = this.bean.getRecordCollectedData(facilityIds, itemInfos, startDate, endDate);
+                    return dataSet;
+                } catch (RemoteException e) {
+                    removeBean();
+                }
+            }
+        }
+
+        return null;
+    }
+
+    /**
+     * 収集した性能値を取得します。
+     * 
+     * @return CollectedDataSet
+     */
+    public CollectedDataSet getRecordCollectedData(
+            final List<String> facilityIdList, 
+            final CollectorItemInfo itemInfo,
+            final Date startDate, 
+            final Date endDate) {
+        CollectedDataSet dataSet = null;
+
+        for (int i = 0; i <= this.errorCount; i++) {
+            if (bean == null) {
+                createBean();
+            }
+
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
+            if (bean != null) {
+                try {
+                	String[] facilityIds = 
+                		facilityIdList.toArray(new String[facilityIdList.size()]);
+
+                	CollectorItemInfo[] itemInfos = new CollectorItemInfo[1];
+                	itemInfos[0] = itemInfo;
+                	
+                	// マネージャから値が格納されたデータセットを取得
+                	dataSet = this.bean.getRecordCollectedData(facilityIds, itemInfos, startDate, endDate);
+                    return dataSet;
+                } catch (RemoteException e) {
+                    removeBean();
+                }
+            }
+        }
+
+        return null;
+    }
+
+//	使用していないメソッドであるため、コメントアウトする　uchiyama
+    /**
+     * 収集した性能値を取得します。
+     * 
+     * @return CollectedDataSet
+     */
+    public CollectedDataSet getRecordCollectedData(
+    		final String collectorID,
+            final String[] facilityIDs, 
+            final CollectorItemInfo[] itemInfos,
+            final Date startDate, 
+            final Date endDate) {
+        CollectedDataSet dataSet = null;
+
+        for (int i = 0; i <= this.errorCount; i++) {
+            if (bean == null) {
+                createBean();
+            }
+
+            // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
+            if (bean != null) {
+                try {
+                	// マネージャから値が格納されたデータセットを取得
+                	dataSet = this.bean.getRecordCollectedData(facilityIDs, itemInfos, startDate, endDate);
                     return dataSet;
                 } catch (RemoteException e) {
                     removeBean();
@@ -393,6 +512,7 @@ public class RecordController {
         return null;
     }
 
+    // FIXME 必要なメソッドなのか？
     /**
      * 収集項目コード情報を取得します。
      * 
@@ -455,7 +575,7 @@ public class RecordController {
      * @param ファシリティID
      * @return デバイス情報セット
      */
-    public List getAvailableCollectorItemList(String facilityId) {
+    public List<CollectorItemInfo> getAvailableCollectorItemList(String facilityId) {
         for (int i = 0; i <= this.errorCount; i++) {
             if (bean == null) {
                 createBean();
@@ -463,8 +583,10 @@ public class RecordController {
 
             // 上記のcreatebean()の結果、やはり生成できない可能性があるため、再度チェック
             if (bean != null) {
-                try {               	
-                    return bean.getAvailableCollectorItemList(facilityId);
+                try {
+                	List<CollectorItemInfo> ret = bean.getAvailableCollectorItemList(facilityId);
+                	
+                    return ret;
                 } catch (RemoteException e) {
                 	e.printStackTrace();
                     removeBean();
