@@ -29,8 +29,10 @@ import org.eclipse.swt.widgets.Label;
 import org.jfree.chart.ChartFactory;
 import org.jfree.chart.ChartPanel;
 import org.jfree.chart.JFreeChart;
+import org.jfree.chart.axis.NumberAxis;
 import org.jfree.chart.axis.ValueAxis;
 import org.jfree.chart.plot.XYPlot;
+import org.jfree.chart.renderer.xy.StackedXYAreaRenderer;
 import org.jfree.chart.renderer.xy.StandardXYItemRenderer;
 import org.jfree.chart.renderer.xy.XYAreaRenderer;
 import org.jfree.data.time.Second;
@@ -143,6 +145,7 @@ public class RecordGraphComposite extends Composite {
         		graphProperty.getTargetFacility(),
                 graphProperty.getTargetItem(),
                 graphProperty.getGraphType(),
+                graphProperty.getGraphForm(),
                 startTime,
                 endTime);
     }
@@ -155,6 +158,14 @@ public class RecordGraphComposite extends Composite {
         return this.m_action.getGraphType();
     }
 
+    /**
+     * グラフの形を返します。
+     *  
+     */
+    public int getGraphForm() {
+        return this.m_action.getGraphForm();
+    }
+
     /**
      * 対象ファシリティのファシリティツリー項目を返します。
      * 
@@ -197,7 +208,8 @@ public class RecordGraphComposite extends Composite {
      * @param graphType グラフ種別
      * @param rangeFixed グラフの縦軸が固定か否かを指定（固定の場合は、0-100）
      */
-    private void createChart(final int graphType, final boolean rangeFixed) {
+    private void createChart(final int graphType, final int graphForm,
+    		final boolean rangeFixed) {
         boolean showDetail;
         if (graphType == GraphProperty.TYPE2 || graphType == GraphProperty.TYPE3) {
             showDetail = true;
@@ -217,33 +229,35 @@ public class RecordGraphComposite extends Composite {
         setRange(0, range);
 
         XYPlot xyplot = m_jfreechart.getXYPlot();
-
-        // レンダラを選択
-        if (graphType == GraphProperty.TYPE1
-                || graphType == GraphProperty.TYPE3) {
-            StandardXYItemRenderer renderer = new StandardXYItemRenderer();
-            if (graphType == GraphProperty.TYPE3) {
-                /** グラフの描画色を固定する */
-                renderer.setSeriesPaint(0, Color.BLACK);
-                renderer.setSeriesPaint(1, Color.BLUE);
-                renderer.setSeriesPaint(2, Color.GREEN);
-                renderer.setSeriesPaint(3, Color.PINK);
-                renderer.setSeriesPaint(4, Color.CYAN);
-                renderer.setSeriesPaint(5, Color.LIGHT_GRAY);
-                renderer.setSeriesPaint(6, Color.MAGENTA);
-                renderer.setSeriesPaint(7, Color.ORANGE);
-                renderer.setSeriesPaint(8, Color.YELLOW);
-                renderer.setSeriesPaint(9, Color.GRAY);
-            }
-            xyplot.setRenderer(renderer);
+		
+        // レンダラと色を選択
+		Color[] color = {Color.RED, Color.BLUE, Color.GREEN, Color.ORANGE, Color.CYAN,
+				Color.MAGENTA, Color.YELLOW, Color.PINK, Color.GRAY, Color.BLACK,
+				Color.LIGHT_GRAY, Color.DARK_GRAY, Color.WHITE};
+        if (graphForm == GraphProperty.FORM2) {
+        	XYAreaRenderer renderer = new XYAreaRenderer();
+			/** グラフの描画色を固定する */
+			for (int i = 0; i < 10; i++) {
+				renderer.setSeriesPaint(i, color[i]);
+			}
+        	xyplot.setRenderer(renderer); // グラフを積み上げ面表示にする。(初期値は折線グラフ)
         } else {
-            XYAreaRenderer renderer = new XYAreaRenderer();
-            xyplot.setRenderer(renderer);
+            StandardXYItemRenderer renderer = new StandardXYItemRenderer();
+			/** グラフの描画色を固定する */
+			for (int i = 0; i < 10; i++) {
+				renderer.setSeriesPaint(i, color[i]);
+			}
+            xyplot.setRenderer(renderer); // グラフを折れ線グラフにする。
         }
 
-        if (rangeFixed) {
+        // 百分率の場合は0-100。しかし、(積み上げ面かつサブスコープ)の場合は除く。
+        // それ以外は下限が0で、上限はオート
+        if (rangeFixed && (graphForm != GraphProperty.FORM2 || graphType != GraphProperty.TYPE3)) {
             ValueAxis valueaxis = xyplot.getRangeAxis();
             valueaxis.setRange(0.0D, 100D);
+        } else {
+            NumberAxis valueaxis = (NumberAxis)(xyplot.getRangeAxis());
+            valueaxis.setAutoRangeIncludesZero(true);
         }
 
         ChartPanel chartPanel = new ChartPanel(m_jfreechart);
@@ -269,6 +283,7 @@ public class RecordGraphComposite extends Composite {
     		final String timeAxisLabel,
             final String valueAxisLabel, 
             final int graphType,
+            final int graphForm,
             final boolean rangeFixed, 
             final int interval, 
             final Date startDate,
@@ -286,7 +301,7 @@ public class RecordGraphComposite extends Composite {
             m_graphFrame = null;
         }
 
-        createChart(graphType, rangeFixed);
+        createChart(graphType, graphForm, rangeFixed);
     }
 
     /**
