@@ -75,7 +75,7 @@ public class ScopeTree implements Serializable {
 	public ScopeTree(
 			FacilityTreeItem treeItem, 
 			List<CollectorDeviceInfoData> deviceDataList, 
-			HashMap<String, String> platformMap,
+			HashMap<String, ArrayList<String>> platformMap,
 			int intervalSec){
 		m_log.debug("ScopeTree コンストラクタ");
 		
@@ -125,22 +125,27 @@ public class ScopeTree implements Serializable {
 			final String facilityName, 
 			final List<CollectorDeviceInfoData> deviceDataList, 
 			String parent,
-			HashMap<String, String> platformMap) {
+			HashMap<String, ArrayList<String>> platformMap) {
 		m_log.debug("addNode facilityId : " + facilityId +  ", " + facilityName);
 		
 		// 既に同じIDのノードが登録されているかどうかを調べる
 		Node node = (Node)m_nodeTable.get(facilityId);
 		String platformId = null;
+		String subPlatformId = null;
+		ArrayList<String> platforms = null;
 		if(node == null){
 			if(platformMap == null) {
 				platformId = Repository.getPlatformId(facilityId);
-				m_log.debug("addNode facilityId : " + facilityId +  ", " + platformId);
+				subPlatformId = Repository.getSubPlatformId(facilityId);
+				m_log.debug("addNode facilityId : " + facilityId +  ", " + platformId + ", " + subPlatformId);
 			}
 			else {
-				platformId = platformMap.get(facilityId);
+				platforms = platformMap.get(facilityId);
+				platformId = platforms.get(0);
+				subPlatformId = platforms.get(1);
 			}
 			
-			node = new Node(facilityId, facilityName, platformId, deviceDataList);
+			node = new Node(facilityId, facilityName, platformId, subPlatformId, deviceDataList);
 		}
 		
 		// 親ファシリティを取得
@@ -329,13 +334,14 @@ public class ScopeTree implements Serializable {
 		
 		// ノードの場合
 		if(facility == null){
+			m_log.debug("Facility is node");
 			facility = (Facility)m_nodeTable.get(facilityId);
 		}
 		
 		if(facility == null){
 			// 無効なノードを参照しようとした
 			m_log.debug("Facility not found : " + facility);
-			return new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDeviceName(), cii.getCollectMethod(), d, value);
+			return new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDisplayName(), d, value);
 		} else {
 			value = facility.calcValue(cii);
 		}
@@ -344,12 +350,12 @@ public class ScopeTree implements Serializable {
 		if(m_log.isDebugEnabled()){
 			m_log.debug("FacilityID : " + facilityId
 					+ "  Code : " + cii.getItemCode()
-					+ "  Device : " + cii.getDeviceName()
+					+ "  DisplayName : " + cii.getDisplayName()
 					+ "  Date : " + d
 					+ "  updateFlg : " + updateFlag);
 		}
 		
-		return new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDeviceName(), cii.getCollectMethod(), d, value);
+		return new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDisplayName(), d, value);
 	}
 
 	/**
@@ -386,11 +392,11 @@ public class ScopeTree implements Serializable {
 		CollectedDataInfo ret;
 		if(m_lastCollectTime == 0){
 			// 今まで一度も収集されていない場合(前回の収集)
-			ret = new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDeviceName(), cii.getCollectMethod(), new Date(), Double.NaN);
+			ret = new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDisplayName(), new Date(), Double.NaN);
 //			ret.setDate(new Date());  // 現時刻を設定
 //			ret.setValue(Double.NaN); // 性能値としてNaNを設定
 		} else {
-			ret = new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDeviceName(), cii.getCollectMethod(), new Date(m_lastCollectTime), value);
+			ret = new CollectedDataInfo(facilityId, cii.getItemCode(), cii.getDisplayName(), new Date(m_lastCollectTime), value);
 //			ret.setDate(new Date(m_lastCollectTime));  // 収集日時を設定
 //			ret.setValue(value);  // 性能値を設定
 		}
@@ -424,7 +430,7 @@ public class ScopeTree implements Serializable {
 	 * 
 	 * @param treeItem FacilityTreeItemの階層オブジェクト
 	 */
-	private void setScopeTree(FacilityTreeItem treeItem, List<CollectorDeviceInfoData> deviceDataList, HashMap<String, String> platformMap) {
+	private void setScopeTree(FacilityTreeItem treeItem, List<CollectorDeviceInfoData> deviceDataList, HashMap<String, ArrayList<String>> platformMap) {
 		FacilityInfo info = treeItem.getData();
 		
 		// ファシリティがスコープの場合
