@@ -49,7 +49,6 @@ import com.clustercontrol.performance.util.FacilityTreeDB;
 import com.clustercontrol.performance.util.JNDIConnectionManager;
 import com.clustercontrol.performance.util.LockManager;
 import com.clustercontrol.performance.util.Repository;
-import com.clustercontrol.performance.bean.CollectMethodConstant;
 import com.clustercontrol.performance.bean.CollectedDataInfo;
 import com.clustercontrol.performance.bean.CollectedDataSet;
 import com.clustercontrol.performance.bean.CollectionTabelDefine;
@@ -117,8 +116,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 	/** 性能値が取得対象がサブスコープ*/
 	public static final int SUB_SCOPE = 1;
 	
-	/** 収集方法 */
-	public static final String COLLECT_METHOD = CollectMethodConstant.SNMP;
+//	/** 収集方法 */ ver3.1より使用しない
+//	public static final String COLLECT_METHOD = PollerProtocolConstant.PROTOCOL_SNMP;
 	
 	private String m_collectorID;  // 収集ID
 	private int m_collectorType;   // 収集種別（リアルタイム もしくは 実績）
@@ -261,7 +260,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 	public Collection<CollectedDataInfo> getRealtimeCollectedData(
 			String facilityID, 
 			String itemCode,
-			String deviceName,
+//			String deviceName,
+			String displayName,
 			int option) { 
 		try {
 			CollectorHome home = JNDIConnectionManager.getCollectorHome();
@@ -273,9 +273,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 						facilityID, 
 						new CollectorItemInfo(
 								m_collectorID,
-								COLLECT_METHOD,
 								itemCode,
-								deviceName
+								displayName
 								));
 				ArrayList<CollectedDataInfo> ret = new ArrayList<CollectedDataInfo>();
 				ret.add(data);
@@ -285,9 +284,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 						facilityID, 
 						new CollectorItemInfo(
 								m_collectorID,
-								COLLECT_METHOD,
 								itemCode,
-								deviceName
+								displayName
 								));
 			} else {
 				return null;
@@ -536,9 +534,8 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 		
 		List<CollectedDataInfo> data = dao.select(
 				item.getCollectorId(), 
-				item.getCollectMethod(),
 				item.getItemCode(), 
-				item.getDeviceName(),
+				item.getDisplayName(),
 				facilityID,
 				startDate, 
 				endDate);
@@ -782,6 +779,7 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
 							bean.getCollectorId(),
 							bean.getFacilityId(),
 							bean.getDeviceName(),
+							bean.getDisplayName(),
 							bean.getIndex(),
 							bean.getDeviceId(),
 							bean.getDeviceType()
@@ -1001,21 +999,20 @@ public abstract class CollectorControllerBean implements javax.ejb.SessionBean,
     	// カテゴリは追加しない
     	if(item.isCategoryItem() == false){   	
     		// 自身をリストに追加
-    		String deviceName = null;
+    		String displayName = null;
     		CollectorDeviceInfoData deviceData = item.getDeviceData();
     		if(deviceData != null){
-    			deviceName = deviceData.getDeviceName();
+    			displayName = deviceData.getDisplayName();
     		}
     		else {
-    			deviceName = "";
+    			displayName = "";
     		}
     		
     		itemInfoList.add(
     				new CollectorItemInfo(
     						null, //collectorId
-    						CollectMethodConstant.SNMP,
     						item.getItemCode(), 
-    						deviceName));
+    						displayName));
     	}
     	
 		// 子要素を再帰的にセットする
