@@ -19,6 +19,8 @@ import java.text.NumberFormat;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
@@ -33,11 +35,14 @@ import com.clustercontrol.bean.MonitorBlockConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
+import com.clustercontrol.performance.util.Repository;
 import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 import com.clustercontrol.performance.bean.CollectedDataInfo;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorDeviceInfoData;
 import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoPK;
 import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
+import com.clustercontrol.util.Messages;
 
 /**
  * リソース監視の閾値判定クラス
@@ -60,6 +65,9 @@ public class RunMonitorPerformance2 extends RunMonitorNumericValueType {
 	/** 収集項目名 */
 	private String m_itemName = null;
 	
+	/** デバイス情報 */
+	private CollectorDeviceInfoData m_deviceData = null;
+	
 	/** 数値フォーマット */
 	protected NumberFormat m_numberFormat = NumberFormat.getNumberInstance();
 	
@@ -97,36 +105,37 @@ public class RunMonitorPerformance2 extends RunMonitorNumericValueType {
 	public void run(String monitorTypeId, String monitorId, CollectedDataInfo data)
 	throws FinderException, RemoveException, JMSException, NamingException, CreateException {
 		
+		//キューコネクションを初期化する
+		super.initialize();
+		
+		String facilityId = data.getFacilityId();
+		
+		if(facilityId == null || "".equals(facilityId)){
+			return;
+		}
+		
+		// 指定のファシリティID配下（ノードの場合は自分）で管理対象有効なノードが存在しない場合
+		if(m_repository.getExecTargetFacilityIdList(facilityId).size() == 0){
+			return;
+		}
+		
+		// 性能値を設定
+		m_value = (float)data.getValue();
+		
+		m_now = new Date();
+		
+		m_monitorTypeId = monitorTypeId;
+		m_monitorId = monitorId;
+		
+		m_priorityMap = new HashMap();
+		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_INFO),		new ArrayList<String>());
+		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_WARNING),	new ArrayList<String>());
+		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_CRITICAL),	new ArrayList<String>());
+		m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_UNKNOWN),	new ArrayList<String>());
+		
+		
 		try 
 		{
-			//キューコネクションを初期化する
-			super.initialize();
-			
-			String facilityId = data.getFacilityId();
-			
-			if(facilityId == null || "".equals(facilityId)){
-				return;
-			}
-			
-			// 指定のファシリティID配下（ノードの場合は自分）で管理対象有効なノードが存在しない場合
-			if(m_repository.getExecTargetFacilityIdList(facilityId).size() == 0){
-				return;
-			}
-			
-			// 性能値を設定
-			m_value = (float)data.getValue();
-			
-			m_now = new Date();
-			
-			m_monitorTypeId = monitorTypeId;
-			m_monitorId = monitorId;
-			
-			m_priorityMap = new HashMap();
-			m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_INFO),		new ArrayList<String>());
-			m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_WARNING),	new ArrayList<String>());
-			m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_CRITICAL),	new ArrayList<String>());
-			m_priorityMap.put(Integer.valueOf(PriorityConstant.TYPE_UNKNOWN),	new ArrayList<String>());
-			
 			// 監視基本情報を設定
 			boolean notify = this.setMonitorInfo(m_monitorTypeId, m_monitorId);
 			if(!notify){
@@ -161,6 +170,25 @@ public class RunMonitorPerformance2 extends RunMonitorNumericValueType {
 						(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && isNode) ||
 						MonitorBlockConstant.TYPE_ALL == m_monitorBlock)){
 					
+					m_log.debug("run() displayName : " + data.getDisplayName());
+					
+					// ノードごとのデバイス情報を取得
+					if(data.getDisplayName() != null && !data.getDisplayName().equals("")) {
+						Repository repository = new Repository();
+						List<CollectorDeviceInfoData> deviceList = repository.getDeviceList(facilityId);
+						
+						Iterator<CollectorDeviceInfoData> itr = deviceList.iterator();
+						while(itr.hasNext()) {
+							
+							CollectorDeviceInfoData device = itr.next();
+							
+							if(device.getDisplayName().equals(data.getDisplayName())){
+								m_deviceData = device;
+								break;
+							}
+						}
+					}
+					
 					// 状態監視へ通知
 					if(data.getDate().getTime() == 0){
 						notify(true, facilityId, priority, new Date());
@@ -212,7 +240,7 @@ public class RunMonitorPerformance2 extends RunMonitorNumericValueType {
 		// 性能管理閾値監視情報を取得
 		MonitorPerfInfoPK pk = new MonitorPerfInfoPK(m_monitorId, m_monitorTypeId);
 		m_perf = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(pk);
-		m_itemName = CollectorItemCodeTable.getFullItemName(m_perf.getItemCode(), m_perf.getDeviceName());
+		m_itemName = CollectorItemCodeTable.getFullItemName(m_perf.getItemCode(), m_perf.getDisplayName());
 	}
 	
 	/**
@@ -295,6 +323,18 @@ public class RunMonitorPerformance2 extends RunMonitorNumericValueType {
 			valueString = "NaN";
 		} else {
 			valueString = m_numberFormat.format(m_value);
+			
+			m_log.debug("RunMonitorPerf messageOrg : " + valueString);
+			
+			// デバイス情報を付加
+			if(m_deviceData != null) {
+				
+				valueString = valueString + "\n" + 
+				Messages.getString("device.name") + " : " + m_deviceData.getDeviceName() + "\n" +
+				Messages.getString("device.index") + " : " + m_deviceData.getIndex();
+				
+				m_log.debug("RunMonitorPerf add DeviceInfo : " + valueString);
+			}
 		}
 		return m_itemName + " : " + valueString;
 	}
