@@ -18,7 +18,7 @@ package com.clustercontrol.performance.operator;
 /**
  * 計算方法が未定義の場合
  */
-public class Undefined extends SnmpOperator {
+public class Undefined extends Operator {
 	@Override
 	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
 		return Double.NaN;
