@@ -26,6 +26,9 @@ import javax.ejb.EJBException;
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.FacilityInfo;
 import com.clustercontrol.bean.FacilityTreeItem;
@@ -34,6 +37,7 @@ import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeRelationL
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeRelationUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeSnapLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeSnapUtil;
+import com.clustercontrol.performance.util.code.CollectorItemCodeTable;
 
 /**
  * DBに対してのファシリティツリー情報の読み書きを実行するクラス
@@ -42,6 +46,8 @@ import com.clustercontrol.performance.monitor.ejb.entity.CollectorScopeSnapUtil;
  */
 public class FacilityTreeDB {
 
+	private static Log m_log = LogFactory.getLog( FacilityTreeDB.class );
+	
 	/**
 	 * スコープツリー情報をDBに書き込みます。
 	 * 
@@ -91,22 +97,28 @@ public class FacilityTreeDB {
 				int typeInt = fItem.getData().getType();
 				String typeStr = null;
 				String platform = null;
+				String subPlatform = null;
 				
 				if(typeInt == FacilityConstant.TYPE_NODE){
 					typeStr = "node";
-					platform = Repository.getPlatformId(fItem.getData().getFacilityId());
+					String facilityId = fItem.getData().getFacilityId();
+					platform = Repository.getPlatformId(facilityId);
+					subPlatform = Repository.getSubPlatformId(facilityId);
 				} else if (typeInt == FacilityConstant.TYPE_SCOPE){
 					typeStr = "scope";
 					platform = "SCOPE";  // プラットフォームは定義できない
+					subPlatform = "SCOPE";  // サブプラットフォームは定義できない
 				} else {
 					typeStr = "comp";
 					platform = "COMP";  // プラットフォームは定義できない
+					subPlatform = "COMP";  // サブプラットフォームは定義できない
 				}
 				
 				CollectorScopeSnapUtil.getLocalHome().create(
 						collectorId, 
 						fItem.getData().getFacilityId(), 
 						platform, 
+						subPlatform,
 						fItem.getData().getFacilityName(), 
 						typeStr);
 				writtenSet.add(fInfo.getFacilityId());
@@ -249,10 +261,8 @@ public class FacilityTreeDB {
 							// まだ親が登録されていないファシリティ(スコープもしくはノード)の場合は、親を設定する。
 							currentItem.setParent(parentItem);
 
-							// 親のスコープの子として自分を登録する（親がいない＝自分がコンポジットの場合を除く）
-							if (parentItem != null) {
-								parentItem.addChildren(currentItem);
-							}
+							// 親のスコープの子として自分を登録する
+							parentItem.addChildren(currentItem);
 						}
 					} else {
 						// 自分が存在しなければ生成する
