@@ -32,8 +32,11 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.bean.PollerProtocolConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.performance.bean.CollectMethodConstant;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstLocal;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstPK;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryCollectMstUtil;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstData;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstLocal;
 import com.clustercontrol.performance.monitor.ejb.entity.CollectorCategoryMstUtil;
@@ -140,7 +143,7 @@ public class CollectorItemCodeTable {
 					}
 					
 					CollectorItemTreeItem ctItem = 
-						new CollectorItemTreeItem(parentItem, codeData, CollectMethodConstant.SNMP, null);
+						new CollectorItemTreeItem(parentItem, codeData, null, null);
 					
 					// 収集項目コードをキーとして登録
 					m_codeTable.put(itemCode, ctItem);
@@ -214,8 +217,8 @@ public class CollectorItemCodeTable {
 		// 処理済の収集項目コードのマップ
 		//　キー ： 収集項目コードとデバイス名をセットにして管理するクラスのインスタンス
 		// 値　：　収集項目要素
-		HashMap<ItemCodeAndDeviceName, CollectorItemTreeItem> createdCodeItemMap = 
-			new HashMap<ItemCodeAndDeviceName, CollectorItemTreeItem>();
+		HashMap<ItemCodeAndDisplayName, CollectorItemTreeItem> createdCodeItemMap = 
+			new HashMap<ItemCodeAndDisplayName, CollectorItemTreeItem>();
 		
 		// 有効な収集項目コードを設定
 		Iterator<CollectorItemCodeMstData> itr = codeSet.iterator();
@@ -249,7 +252,7 @@ public class CollectorItemCodeTable {
 			final String collectMethod,
 			final Set<CollectorDeviceInfoData> deviceSet,
 			final HashMap<String, CollectorItemTreeItem> categoryMap,
-			HashMap<ItemCodeAndDeviceName, CollectorItemTreeItem> createdCodeMap){
+			HashMap<ItemCodeAndDisplayName, CollectorItemTreeItem> createdCodeMap){
 		// 既に生成済みのコードの場合は抜ける
 		if(createdCodeSet.contains(itemCodeData.getItemCode())){
 			return;
@@ -272,7 +275,7 @@ public class CollectorItemCodeTable {
 			if(itemCodeData.getDeviceSupport() == YesNoConstant.TYPE_NO){
 				CollectorItemTreeItem item = new CollectorItemTreeItem(parentItem, itemCodeData, collectMethod, null);
 				// 作成済みマップに登録する
-				createdCodeMap.put(new ItemCodeAndDeviceName(itemCodeData.getItemCode(), null), item);
+				createdCodeMap.put(new ItemCodeAndDisplayName(itemCodeData.getItemCode(), null), item);
 			} else {
 				// デバイスのリスト全てをチェックする
 				Iterator<CollectorDeviceInfoData> dItr = deviceSet.iterator();
@@ -282,7 +285,7 @@ public class CollectorItemCodeTable {
 					if(itemCodeData.getDeviceType().equals(dData.getDeviceType())){
 						CollectorItemTreeItem item = new CollectorItemTreeItem(parentItem, itemCodeData, collectMethod, dData);
 						// 作成済みマップに登録する
-						createdCodeMap.put(new ItemCodeAndDeviceName(itemCodeData.getItemCode(), dData.getDeviceName()), item);
+						createdCodeMap.put(new ItemCodeAndDisplayName(itemCodeData.getItemCode(), dData.getDisplayName()), item);
 					}
 				}
 			}
@@ -293,7 +296,7 @@ public class CollectorItemCodeTable {
 			if(itemCodeData.getDeviceSupport() == YesNoConstant.TYPE_NO){
 				// 生成済みの要素から親の要素を取得する
 				CollectorItemTreeItem parentItem = 
-					createdCodeMap.get(new ItemCodeAndDeviceName(itemCodeData.getParentItemCode(), null));
+					createdCodeMap.get(new ItemCodeAndDisplayName(itemCodeData.getParentItemCode(), null));
 				
 				// まだ生成されていない場合
 				if(parentItem == null){
@@ -308,7 +311,7 @@ public class CollectorItemCodeTable {
 					}
 					
 					// 生成した親の要素を取得する
-					parentItem = createdCodeMap.get(new ItemCodeAndDeviceName(itemCodeData.getParentItemCode(), null));
+					parentItem = createdCodeMap.get(new ItemCodeAndDisplayName(itemCodeData.getParentItemCode(), null));
 					
 					if(parentItem == null){
 						// 親が存在しないため、カテゴリを親要素とする
@@ -318,7 +321,7 @@ public class CollectorItemCodeTable {
 				
 				CollectorItemTreeItem item = new CollectorItemTreeItem(parentItem, itemCodeData, collectMethod, null);
 				// 作成済みマップに登録する
-				createdCodeMap.put(new ItemCodeAndDeviceName(itemCodeData.getItemCode(), null), item);				
+				createdCodeMap.put(new ItemCodeAndDisplayName(itemCodeData.getItemCode(), null), item);				
 			} else {
 				// デバイスをサポートしている場合
 				// デバイスのリスト全てをチェックする
@@ -329,7 +332,7 @@ public class CollectorItemCodeTable {
 					if(itemCodeData.getDeviceType().equals(dData.getDeviceType())){
 						// 生成済みの要素から親の要素を取得する
 						CollectorItemTreeItem parentItem = 
-							createdCodeMap.get(new ItemCodeAndDeviceName(itemCodeData.getParentItemCode(), dData.getDeviceName()));
+							createdCodeMap.get(new ItemCodeAndDisplayName(itemCodeData.getParentItemCode(), dData.getDisplayName()));
 						
 						// まだ生成されていない場合
 						if(parentItem == null){
@@ -344,7 +347,7 @@ public class CollectorItemCodeTable {
 							}
 							
 							// 生成した親の要素を取得する
-							parentItem = createdCodeMap.get(new ItemCodeAndDeviceName(itemCodeData.getParentItemCode(), dData.getDeviceName()));
+							parentItem = createdCodeMap.get(new ItemCodeAndDisplayName(itemCodeData.getParentItemCode(), dData.getDisplayName()));
 							
 							if(parentItem == null){
 								// 親が存在しないため、カテゴリを親要素とする
@@ -354,7 +357,7 @@ public class CollectorItemCodeTable {
 						
 						CollectorItemTreeItem item = new CollectorItemTreeItem(parentItem, itemCodeData, collectMethod, dData);
 						// 作成済みマップに登録する
-						createdCodeMap.put(new ItemCodeAndDeviceName(itemCodeData.getItemCode(), dData.getDeviceName()), item);				
+						createdCodeMap.put(new ItemCodeAndDisplayName(itemCodeData.getItemCode(), dData.getDisplayName()), item);				
 					}
 				}
 			}
@@ -362,33 +365,79 @@ public class CollectorItemCodeTable {
 		createdCodeSet.add(itemCodeData.getItemCode());
 	}
 
-	private static class ItemCodeAndDeviceName{
+//	private static class ItemCodeAndDeviceName{
+//		private String itemCode;
+//		private String deviceName;
+//		
+//		public ItemCodeAndDeviceName(String itemCode, String deviceName){
+//			this.itemCode = itemCode;
+//			this.deviceName = deviceName;
+//		}
+//		
+//		public boolean equals(Object other) {		
+//			if (other instanceof ItemCodeAndDeviceName) {
+//				ItemCodeAndDeviceName info = (ItemCodeAndDeviceName)other;
+//				if (this.itemCode == null && this.deviceName == null){
+//					if (info.itemCode == null && info.deviceName == null){
+//						return true;
+//					}
+//				} else if (this.itemCode == null && this.deviceName != null){
+//					if (info.itemCode == null && this.deviceName.equals(info.deviceName)){
+//						return true;
+//					}
+//				} else if (this.itemCode != null && this.deviceName == null){
+//					if (this.itemCode.equals(info.itemCode) && info.deviceName == null){
+//						return true;
+//					}
+//				} else {
+//					if (this.itemCode.equals(info.itemCode)){
+//						return this.deviceName.equals(info.deviceName);
+//					}
+//				}
+//				return false;
+//			} else {
+//				return false;
+//			}
+//		}
+//
+//		public int hashCode() {
+//			int result = 17;
+//
+//			result = 37 * result + ((this.itemCode != null) ? this.itemCode.hashCode() : 0);
+//
+//			result = 37 * result + ((this.deviceName != null) ? this.deviceName.hashCode() : 0);
+//
+//			return result;
+//		}
+//	}
+	
+	private static class ItemCodeAndDisplayName{
 		private String itemCode;
-		private String deviceName;
+		private String displayName;
 		
-		public ItemCodeAndDeviceName(String itemCode, String deviceName){
+		public ItemCodeAndDisplayName(String itemCode, String displayName){
 			this.itemCode = itemCode;
-			this.deviceName = deviceName;
+			this.displayName = displayName;
 		}
 		
 		public boolean equals(Object other) {		
-			if (other instanceof ItemCodeAndDeviceName) {
-				ItemCodeAndDeviceName info = (ItemCodeAndDeviceName)other;
-				if (this.itemCode == null && this.deviceName == null){
-					if (info.itemCode == null && info.deviceName == null){
+			if (other instanceof ItemCodeAndDisplayName) {
+				ItemCodeAndDisplayName info = (ItemCodeAndDisplayName)other;
+				if (this.itemCode == null && this.displayName == null){
+					if (info.itemCode == null && info.displayName == null){
 						return true;
 					}
-				} else if (this.itemCode == null && this.deviceName != null){
-					if (info.itemCode == null && this.deviceName.equals(info.deviceName)){
+				} else if (this.itemCode == null && this.displayName != null){
+					if (info.itemCode == null && this.displayName.equals(info.displayName)){
 						return true;
 					}
-				} else if (this.itemCode != null && this.deviceName == null){
-					if (this.itemCode.equals(info.itemCode) && info.deviceName == null){
+				} else if (this.itemCode != null && this.displayName == null){
+					if (this.itemCode.equals(info.itemCode) && info.displayName == null){
 						return true;
 					}
 				} else {
 					if (this.itemCode.equals(info.itemCode)){
-						return this.deviceName.equals(info.deviceName);
+						return this.displayName.equals(info.displayName);
 					}
 				}
 				return false;
@@ -402,45 +451,105 @@ public class CollectorItemCodeTable {
 
 			result = 37 * result + ((this.itemCode != null) ? this.itemCode.hashCode() : 0);
 
-			result = 37 * result + ((this.deviceName != null) ? this.deviceName.hashCode() : 0);
+			result = 37 * result + ((this.displayName != null) ? this.displayName.hashCode() : 0);
 
 			return result;
 		}
-	}	
+	}
 	
-	public static class DeviceTypeAndDeviceName{
+//	public static class DeviceTypeAndDeviceName{
+//		private String deviceType;
+//		private String deviceName;
+//		
+//		public DeviceTypeAndDeviceName(String deviceType, String deviceName){
+//			this.deviceType = deviceType;
+//			if(deviceName != null){
+//				this.deviceName = deviceName;
+//			}
+//			else {
+//				this.deviceName = "";
+//			}
+//		}
+//		
+//		public boolean equals(Object other) {
+//			if (other instanceof DeviceTypeAndDeviceName) {
+//				DeviceTypeAndDeviceName info = (DeviceTypeAndDeviceName)other;
+//				
+//				if (this.deviceType == null && this.deviceName == null){
+//					if (info.deviceType == null && info.deviceName == null){
+//						return true;
+//					}
+//				} else if (this.deviceType == null && this.deviceName != null){
+//					if (info.deviceType == null && this.deviceName.equals(info.deviceName)){
+//						return true;
+//					}
+//				} else if (this.deviceType != null && this.deviceName == null){
+//					if (this.deviceType.equals(info.deviceType) && info.deviceName == null){
+//						return true;
+//					}
+//				} else {
+//					if (this.deviceType.equals(info.deviceType)){
+//						return this.deviceName.equals(info.deviceName);
+//					}
+//				}
+//				return false;
+//			} else {
+//				return false;
+//			}
+//		}
+//
+//		public int hashCode() {
+//			int result = 17;
+//
+//			result = 37 * result + ((this.deviceType != null) ? this.deviceType.hashCode() : 0);
+//
+//			result = 37 * result + ((this.deviceName != null) ? this.deviceName.hashCode() : 0);
+//
+//			return result;
+//		}
+//
+//		public String getDeviceType() {
+//			return deviceType;
+//		}
+//
+//		public String getDeviceName() {
+//			return deviceName;
+//		}
+//	}	
+	
+	public static class DeviceTypeAndDisplayName{
 		private String deviceType;
-		private String deviceName;
+		private String displayName;
 		
-		public DeviceTypeAndDeviceName(String deviceType, String deviceName){
+		public DeviceTypeAndDisplayName(String deviceType, String displayName){
 			this.deviceType = deviceType;
-			if(deviceName != null){
-				this.deviceName = deviceName;
+			if(displayName != null){
+				this.displayName = displayName;
 			}
 			else {
-				this.deviceName = "";
+				this.displayName = "";
 			}
 		}
 		
 		public boolean equals(Object other) {
-			if (other instanceof DeviceTypeAndDeviceName) {
-				DeviceTypeAndDeviceName info = (DeviceTypeAndDeviceName)other;
+			if (other instanceof DeviceTypeAndDisplayName) {
+				DeviceTypeAndDisplayName info = (DeviceTypeAndDisplayName)other;
 				
-				if (this.deviceType == null && this.deviceName == null){
-					if (info.deviceType == null && info.deviceName == null){
+				if (this.deviceType == null && this.displayName == null){
+					if (info.deviceType == null && info.displayName == null){
 						return true;
 					}
-				} else if (this.deviceType == null && this.deviceName != null){
-					if (info.deviceType == null && this.deviceName.equals(info.deviceName)){
+				} else if (this.deviceType == null && this.displayName != null){
+					if (info.deviceType == null && this.displayName.equals(info.displayName)){
 						return true;
 					}
-				} else if (this.deviceType != null && this.deviceName == null){
-					if (this.deviceType.equals(info.deviceType) && info.deviceName == null){
+				} else if (this.deviceType != null && this.displayName == null){
+					if (this.deviceType.equals(info.deviceType) && info.displayName == null){
 						return true;
 					}
 				} else {
 					if (this.deviceType.equals(info.deviceType)){
-						return this.deviceName.equals(info.deviceName);
+						return this.displayName.equals(info.displayName);
 					}
 				}
 				return false;
@@ -454,7 +563,7 @@ public class CollectorItemCodeTable {
 
 			result = 37 * result + ((this.deviceType != null) ? this.deviceType.hashCode() : 0);
 
-			result = 37 * result + ((this.deviceName != null) ? this.deviceName.hashCode() : 0);
+			result = 37 * result + ((this.displayName != null) ? this.displayName.hashCode() : 0);
 
 			return result;
 		}
@@ -463,11 +572,66 @@ public class CollectorItemCodeTable {
 			return deviceType;
 		}
 
-		public String getDeviceName() {
-			return deviceName;
+		public String getDisplayName() {
+			return displayName;
 		}
 	}	
 	
+	private static class PlatformIdAndSubPlatformId {
+		private String m_platformId;
+		private String m_subPlatformId;
+		
+		public PlatformIdAndSubPlatformId(String platformId, String subPlatformId){
+			m_platformId = platformId;
+			m_subPlatformId = subPlatformId;
+		}
+		
+		public String getPlatformId(){
+			return m_platformId;
+		}
+		
+		public String getSubPlatformId(){
+			return m_subPlatformId;
+		}
+		
+		public boolean equals(Object other) {
+			if (other instanceof PlatformIdAndSubPlatformId) {
+				PlatformIdAndSubPlatformId info = (PlatformIdAndSubPlatformId)other;
+				
+				if (this.m_platformId == null && this.m_subPlatformId == null){
+					if (info.m_platformId == null && info.m_subPlatformId == null){
+						return true;
+					}
+				} else if (this.m_platformId == null && this.m_subPlatformId != null){
+					if (info.m_platformId == null && this.m_subPlatformId.equals(info.m_subPlatformId)){
+						return true;
+					}
+				} else if (this.m_platformId != null && this.m_subPlatformId == null){
+					if (this.m_platformId.equals(info.m_platformId) && info.m_subPlatformId == null){
+						return true;
+					}
+				} else {
+					if (this.m_platformId.equals(info.m_platformId)){
+						return this.m_subPlatformId.equals(info.m_subPlatformId);
+					}
+				}
+				return false;
+			} else {
+				return false;
+			}
+		}
+
+		public int hashCode() {
+			int result = 17;
+
+			result = 37 * result + ((this.m_platformId != null) ? this.m_platformId.hashCode() : 0);
+
+			result = 37 * result + ((this.m_subPlatformId != null) ? this.m_subPlatformId.hashCode() : 0);
+
+			return result;
+		}
+	}
+	
 	/**
 	 * 指定の収集IDの収集のデバイス情報をDBから取得し収集項目ツリーを生成して返します。
 	 * 指定の収集IDがnullの場合はリポジトリからデバイス情報を取得する。
@@ -477,20 +641,32 @@ public class CollectorItemCodeTable {
 	 * @return
 	 */
 	public static CollectorItemTreeItem[] getCollectorTree(String facilityId, String collectorId){
-		return getCollectorTree(facilityId, collectorId, CollectMethodConstant.SNMP);
+		return getCollectorTree(facilityId, collectorId, null);
 	}
 
+	/**
+	 * 指定の収集IDの収集のデバイス情報をDBから取得し収集項目ツリーを生成して返します。
+	 * 指定の収集IDがnullの場合はリポジトリからデバイス情報を取得する。
+	 * 
+	 * @param facilityId ファシリティID
+	 * @param collectorId 収集ID
+	 * @param collectMethod 収集方法
+	 * @return
+	 */
 	private static CollectorItemTreeItem[] getCollectorTree(String facilityId, String collectorId, String collectMethod){
 		Set<CollectorDeviceInfoData> deviceSet = new HashSet<CollectorDeviceInfoData>();
 
 		// 全てのノードのプラットフォームIDのセット
-		Set<String> platformSet = new HashSet<String>();
+		Set<PlatformIdAndSubPlatformId> platformCombSet = new HashSet<PlatformIdAndSubPlatformId>();
 		
-		// いずれかのノードに含まれる（OR条件）デバイス名の情報
-		Set<DeviceTypeAndDeviceName> deviceSetAdd = new HashSet<DeviceTypeAndDeviceName>();
+		// いずれかのノードに含まれる（OR条件）デバイス名の情報 (Ver3.1.0現在では未使用)
+		Set<DeviceTypeAndDisplayName> deviceSetAdd = new HashSet<DeviceTypeAndDisplayName>();
 		
 		// 全てのノードに含まれる（AND条件）デバイス名の情報
-		Set<DeviceTypeAndDeviceName> deviceSetRetain = null;
+		Set<DeviceTypeAndDisplayName> deviceSetRetain = null;
+		
+		// DeviceTypeAndDisplayNameに対応するdeviceName情報
+		HashMap<DeviceTypeAndDisplayName, String> deviceNameMap = new HashMap<DeviceTypeAndDisplayName, String>();
 		
 		if(collectorId == null){
 			if(facilityId != null){
@@ -501,20 +677,25 @@ public class CollectorItemCodeTable {
 				if(repository.isNode(facilityId)){
 					// プラットフォームIDを取得
 					String platformId = Repository.getPlatformId(facilityId);
-					platformSet.add(platformId);
+					String subPlatformId = Repository.getSubPlatformId(facilityId);
 					
-					List<CollectorDeviceInfoData> deviceList = repository.getDeviceList(facilityId);		
+					PlatformIdAndSubPlatformId platformIdComb = new PlatformIdAndSubPlatformId(platformId, subPlatformId);
+					platformCombSet.add(platformIdComb);
+					
+					List<CollectorDeviceInfoData> deviceList = repository.getDeviceList(facilityId);
 					Iterator<CollectorDeviceInfoData> itr = deviceList.iterator();
 					
-					Set<DeviceTypeAndDeviceName> tmp = new HashSet<DeviceTypeAndDeviceName>();
+					Set<DeviceTypeAndDisplayName> tmp = new HashSet<DeviceTypeAndDisplayName>();
 					while(itr.hasNext()){
 						CollectorDeviceInfoData data = itr.next();
 						
-						tmp.add(new DeviceTypeAndDeviceName(data.getDeviceType(), data.getDeviceName()));
+						DeviceTypeAndDisplayName tan = new DeviceTypeAndDisplayName(data.getDeviceType(), data.getDisplayName());
+						tmp.add(tan);
+						deviceNameMap.put(tan, data.getDeviceName());
 					}
 					
 					deviceSetAdd.addAll(tmp);
-					deviceSetRetain = new HashSet<DeviceTypeAndDeviceName>(tmp);
+					deviceSetRetain = new HashSet<DeviceTypeAndDisplayName>(tmp);
 				}
 				// ファシリティがスコープの場合
 				else {
@@ -530,17 +711,22 @@ public class CollectorItemCodeTable {
 						
 						// プラットフォームIDを取得
 						String platformId = Repository.getPlatformId(nodeFacilityId);
-						platformSet.add(platformId);
+						String subPlatformId = Repository.getSubPlatformId(nodeFacilityId);
+						
+						PlatformIdAndSubPlatformId platformIdComb = new PlatformIdAndSubPlatformId(platformId, subPlatformId);
+						platformCombSet.add(platformIdComb);
 						
 						// デバイス情報を取得
 						List<CollectorDeviceInfoData> deviceList = repository.getDeviceList(nodeFacilityId);		
 						Iterator<CollectorDeviceInfoData> itr = deviceList.iterator();
 						
 						// 現在着目しているノードに含まれる全てのデバイスを格納
-						Set<DeviceTypeAndDeviceName> tmp = new HashSet<DeviceTypeAndDeviceName>();
+						Set<DeviceTypeAndDisplayName> tmp = new HashSet<DeviceTypeAndDisplayName>();
 						while(itr.hasNext()){
 							CollectorDeviceInfoData data = itr.next();
-							tmp.add(new DeviceTypeAndDeviceName(data.getDeviceType(), data.getDeviceName()));
+							DeviceTypeAndDisplayName tan = new DeviceTypeAndDisplayName(data.getDeviceType(), data.getDisplayName());
+							tmp.add(tan);
+							deviceNameMap.put(tan, data.getDeviceName());
 						}
 						
 						// 全て追加する
@@ -548,7 +734,7 @@ public class CollectorItemCodeTable {
 						
 						// 同じものだけ追加する
 						if(deviceSetRetain == null){
-							deviceSetRetain = new HashSet<DeviceTypeAndDeviceName>(tmp);
+							deviceSetRetain = new HashSet<DeviceTypeAndDisplayName>(tmp);
 						} else {
 							deviceSetRetain.retainAll(tmp);
 						}
@@ -586,7 +772,11 @@ public class CollectorItemCodeTable {
 				
 				// ファシリティ種別がノードの場合
 				if(FacilityConstant.TYPE_NODE_STRING.equals(bean.getFacilityType())){
-					platformSet.add(bean.getPlatformId());
+					
+					String platformId = bean.getPlatformId();
+					String subPlatformId = bean.getSubPlatformId();
+					
+					platformCombSet.add(new PlatformIdAndSubPlatformId(platformId, subPlatformId));
 
 					// ノード毎のデバイス情報を取得し、
 					// どれかに含まれるデバイスセット（deviceSetAdd）、
@@ -597,14 +787,16 @@ public class CollectorItemCodeTable {
 					Iterator<CollectorDeviceInfoLocal> nodeItr = col.iterator();
 
 					// ターゲットのノードが保持するデバイスの情報を格納するセット
-					Set<DeviceTypeAndDeviceName> tmp = new HashSet<DeviceTypeAndDeviceName>();
+					Set<DeviceTypeAndDisplayName> tmp = new HashSet<DeviceTypeAndDisplayName>();
 					while(nodeItr.hasNext()){
 						CollectorDeviceInfoLocal deviceInfo = nodeItr.next();
 
 						// ターゲットのノードのデバイス情報のみ抽出する
 						if(targetFacilityId.equals(deviceInfo.getFacilityId())){
-							tmp.add(new DeviceTypeAndDeviceName(
-									deviceInfo.getDeviceType(), deviceInfo.getDeviceName()));
+							DeviceTypeAndDisplayName tan = 
+								new DeviceTypeAndDisplayName(deviceInfo.getDeviceType(), deviceInfo.getDisplayName());
+							tmp.add(tan);
+							deviceNameMap.put(tan, deviceInfo.getDeviceName());
 						}
 					}
 
@@ -613,7 +805,7 @@ public class CollectorItemCodeTable {
 
 					// 同じものだけ追加する
 					if(deviceSetRetain == null){
-						deviceSetRetain = new HashSet<DeviceTypeAndDeviceName>(tmp);
+						deviceSetRetain = new HashSet<DeviceTypeAndDisplayName>(tmp);
 					} else {
 						deviceSetRetain.retainAll(tmp);
 					}
@@ -626,24 +818,45 @@ public class CollectorItemCodeTable {
 		
 		// 選択不可な収集項目コード情報のセット
 		Set<CollectorItemCodeMstData> disableCodeSet = new HashSet<CollectorItemCodeMstData>();
-
-		// 計算方法管理テーブルから指定の収集方法、プラットフォームで収集可能な収集項目コードを取得する
-		Collection<CollectorItemCalcMethodMstLocal> calsMethods;
-		try {
-			calsMethods = CollectorItemCalcMethodMstUtil.getLocalHome().findAll();
-		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
-			return null;
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(), e);
-			return null;
-		}
 		
-		Iterator<String> platformItr = platformSet.iterator();
+		Iterator<PlatformIdAndSubPlatformId> platformItr = platformCombSet.iterator();
 		// プラットフォームごとにループをまわす
 		while(platformItr.hasNext()){
-			String platformId = platformItr.next();
+			PlatformIdAndSubPlatformId platformComb = platformItr.next();
 
+			m_log.debug("getCollectorTree() " +
+					"platformId : " + platformComb.getPlatformId() + 
+					", subPlatformId : " + platformComb.getSubPlatformId() +
+					", collectMethod : " + collectMethod);
+			
+			// プラットフォーム、サブプラットフォーム単位のカテゴリコード、収集方法を取得
+			Collection<CollectorCategoryCollectMstLocal> collects;
+			// プラットフォーム、サブプラットフォーム単位の収集方法、アイテムコード、算出方法を取得
+			Collection<CollectorItemCalcMethodMstLocal> calsMethods;
+			try {
+				collects = CollectorCategoryCollectMstUtil.getLocalHome().findByPlatformIdAndSubPlatformId(
+						platformComb.getPlatformId(),
+						platformComb.getSubPlatformId());
+				
+				calsMethods = CollectorItemCalcMethodMstUtil.getLocalHome().findByPlatformIdAndSubPlatformId(
+						platformComb.getPlatformId(),
+						platformComb.getSubPlatformId());
+			} catch (FinderException e) {
+				m_log.error(e.getMessage(), e);
+				return null;
+			} catch (NamingException e) {
+				m_log.error(e.getMessage(), e);
+				return null;
+			}
+			
+			// categoryCodeをキーにcollectMethodを取得するマップ
+			HashMap<String, String> categoryMap = new HashMap<String, String>();
+			Iterator<CollectorCategoryCollectMstLocal> collectsItr = collects.iterator();
+			while(collectsItr.hasNext()) {
+				CollectorCategoryCollectMstLocal collect = collectsItr.next();
+				categoryMap.put(collect.getCategoryCode(), collect.getCollectMethod());
+			}
+			
 			// プラットフォームごとに収集可能な収集項目コードのリストを求める
 			HashSet<CollectorItemCodeMstData> tmpByPlatform = new HashSet<CollectorItemCodeMstData>();
 			
@@ -651,9 +864,42 @@ public class CollectorItemCodeTable {
 			Iterator<CollectorItemCalcMethodMstLocal> itr = calsMethods.iterator();
 			while(itr.hasNext()){
 				CollectorItemCalcMethodMstLocal bean = itr.next();
-
-				// 収集方法が一致する場合
-				if (collectMethod.equals(bean.getCollectMethod())){
+					
+				// 収集方法に拠らない場合
+				if (collectMethod == null || collectMethod.equals("")){
+					
+					CollectorItemCodeMstLocal codeBean;
+					try {
+						codeBean = CollectorItemCodeMstUtil.getLocalHome().findByPrimaryKey(bean.getItemCode());
+					} catch (FinderException e) {
+						m_log.error(e.getMessage(), e);
+						return null;
+					} catch (NamingException e) {
+						m_log.error(e.getMessage(), e);
+						return null;
+					}
+					
+					// カテゴリ別収集情報の収集方法と収集項目マスタの収集方法を比較し、同じならば追加する
+					if(categoryMap.get(codeBean.getCategoryCode()) != null && 
+							categoryMap.get(codeBean.getCategoryCode()).equals(bean.getCollectMethod())) {
+						// 収集項目コードマスタ情報のDTOを作成
+						CollectorItemCodeMstData codeData = new CollectorItemCodeMstData(
+								codeBean.getItemCode(),
+								codeBean.getCategoryCode(),
+								codeBean.getParentItemCode(),
+								codeBean.getItemName(),
+								codeBean.getMeasure(),
+								codeBean.getDeviceSupport(),
+								codeBean.getDeviceType(),
+								codeBean.getGraphRange()
+						);
+						
+						tmpByPlatform.add(codeData);
+					}
+					
+				}
+				// 収集方法が一致する場合(収集方法が指定されている場合)
+				else if(collectMethod.equals(bean.getCollectMethod())){
 					CollectorItemCodeMstLocal codeBean;
 					try {
 						codeBean = CollectorItemCodeMstUtil.getLocalHome().findByPrimaryKey(bean.getItemCode());
@@ -665,20 +911,21 @@ public class CollectorItemCodeTable {
 						return null;
 					}
 
-					// 収集項目コードマスタ情報のDTOを作成
-					CollectorItemCodeMstData codeData = new CollectorItemCodeMstData(
-							codeBean.getItemCode(),
-							codeBean.getCategoryCode(),
-							codeBean.getParentItemCode(),
-							codeBean.getItemName(),
-							codeBean.getMeasure(),
-							codeBean.getDeviceSupport(),
-							codeBean.getDeviceType(),
-							codeBean.getGraphRange()
-					);
-
-					// 収集方法およびプラットフォームIDが一致する場合
-					if(platformId.equals(bean.getPlatformId())){
+					// カテゴリ別収集情報の収集方法と収集項目マスタの収集方法を比較し、同じならば追加する
+					if(categoryMap.get(codeBean.getCategoryCode()) != null && 
+							categoryMap.get(codeBean.getCategoryCode()).equals(bean.getCollectMethod())) {
+						// 収集項目コードマスタ情報のDTOを作成
+						CollectorItemCodeMstData codeData = new CollectorItemCodeMstData(
+								codeBean.getItemCode(),
+								codeBean.getCategoryCode(),
+								codeBean.getParentItemCode(),
+								codeBean.getItemName(),
+								codeBean.getMeasure(),
+								codeBean.getDeviceSupport(),
+								codeBean.getDeviceType(),
+								codeBean.getGraphRange()
+						);
+					
 						tmpByPlatform.add(codeData);
 					}
 				}
@@ -697,20 +944,21 @@ public class CollectorItemCodeTable {
 
 		// デバイスがひとつもない場合はここで空のセットを初期化する
 		if(deviceSetRetain == null){
-			deviceSetRetain = new HashSet<DeviceTypeAndDeviceName>();
+			deviceSetRetain = new HashSet<DeviceTypeAndDisplayName>();
 		}
 		
 		// デバイス情報のセットを生成
 		// デバイス情報を設定
-		Iterator<DeviceTypeAndDeviceName> deviceItr = deviceSetRetain.iterator();
+		Iterator<DeviceTypeAndDisplayName> deviceItr = deviceSetRetain.iterator();
 		while(deviceItr.hasNext()){
-			DeviceTypeAndDeviceName info = deviceItr.next();
+			DeviceTypeAndDisplayName info = deviceItr.next();
 
 			// デバイス名とデバイス種別のみのインスタンスを生成
 			CollectorDeviceInfoData deviceData = new CollectorDeviceInfoData(
 					null,  // 収集ID
 					null,  // ファシリティID
-					info.getDeviceName(),
+					deviceNameMap.get(info),
+					info.getDisplayName(),
 					null,
 					null,
 					info.getDeviceType());
@@ -730,19 +978,19 @@ public class CollectorItemCodeTable {
 	}
 	
 	/**
-	 * 収集項目コードとデバイス名から収集項目表示用文字列を生成し返します。
-	 * 形式 ：　収集名[デバイス名]
+	 * 収集項目コードとリポジトリ表示名から収集項目表示用文字列を生成し返します。
+	 * 形式 ：　収集名[リポジトリ表示名]
 	 * 
 	 * @param itemCode 収集項目コード
-	 * @param deviceName デバイス名
+	 * @param displayName リポジトリ表示名
 	 * @return 収集項目表示
 	 */
-	public static String getFullItemName(String itemCode, String deviceName){
+	public static String getFullItemName(String itemCode, String displayName){
 		try {
 			CollectorItemCodeMstLocal bean = CollectorItemCodeMstUtil.getLocalHome().findByPrimaryKey(itemCode);
 			String itemName = bean.getItemName();
 			if(bean.getDeviceSupport().intValue() == YesNoConstant.TYPE_YES){
-				itemName = itemName + "[" + deviceName + "]";
+				itemName = itemName + "[" + displayName + "]";
 			}
 			return itemName;
 		} catch (FinderException e) {
@@ -760,4 +1008,5 @@ public class CollectorItemCodeTable {
 	public static HashMap<String, CollectorItemTreeItem> getItemCodeMap(){
 		return m_codeTable;
 	}
+	
 }
\ No newline at end of file
