@@ -16,6 +16,10 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.process.factory;
 
 import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
@@ -26,13 +30,22 @@ import javax.rmi.PortableRemoteObject;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.PollerProtocolConstant;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstLocal;
+import com.clustercontrol.performance.monitor.ejb.entity.CollectorPollingMstUtil;
 import com.clustercontrol.poller.CollectorAlreadyExistException;
 import com.clustercontrol.poller.FacilityNotFoundException;
 import com.clustercontrol.poller.NotInitializedException;
-import com.clustercontrol.poller.snmp.SnmpPoller;
-import com.clustercontrol.poller.snmp.SnmpPollerManager;
-import com.clustercontrol.process.bean.SnmpSharedTableConstant;
-import com.clustercontrol.process.util.SnmpProcConnectionManager;
+import com.clustercontrol.poller.PollerManager;
+import com.clustercontrol.poller.PollingController;
+import com.clustercontrol.process.bean.SharedTableConstant;
+import com.clustercontrol.process.ejb.entity.MonitorProcessMethodMstLocal;
+import com.clustercontrol.process.ejb.entity.MonitorProcessMethodMstLocalHome;
+import com.clustercontrol.process.ejb.entity.MonitorProcessMethodMstPK;
+import com.clustercontrol.process.ejb.entity.MonitorProcessMethodMstUtil;
+import com.clustercontrol.process.util.PollingDataManager;
+import com.clustercontrol.process.util.PollingProcConnectionManager;
+import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
@@ -50,8 +63,31 @@ public class ModifyPollingSchedule {
 	
 	protected static Log m_log = LogFactory.getLog( ModifyPollingSchedule.class );
 	
+	private static final HashMap<String, String> platformMethodMap = new HashMap<String, String>();
+	
+	static{
+		
+		// 
+		try {
+			Collection<MonitorProcessMethodMstLocal> processMethod = MonitorProcessMethodMstUtil.getLocalHome().findAll();
+			Iterator<MonitorProcessMethodMstLocal> itr = processMethod.iterator();
+			MonitorProcessMethodMstLocal local = null;
+			
+			while(itr.hasNext()) {
+				local = itr.next();
+				platformMethodMap.put(local.getPlatformId(), local.getCollectMethod());
+			}
+			
+		} catch (FinderException e) {
+			m_log.warn("InternalError",e);
+		} catch (NamingException e) {
+			m_log.warn("InternalError",e);
+		}
+	}
+	
+	
 	/**
-	 * SNMPポーリングに登録します。<BR>
+	 * ポーリングに登録します。<BR>
 	 * 
 	 * @param parentFacilityId ファシリティID
 	 * @param interval 収集間隔(秒)
@@ -66,7 +102,7 @@ public class ModifyPollingSchedule {
 			
 			try{
 				// SNMP収集値の共有テーブルをルックアップ
-		        SharedTable sst = SnmpProcConnectionManager.getSnmpSharedTable();
+		        SharedTable sst = PollingProcConnectionManager.getSharedTable();
 				
 				// ファシリティIDの配下全ての一覧を取得
 				RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
@@ -94,19 +130,28 @@ public class ModifyPollingSchedule {
 						
 						// ポーラを生成する
 						InitialContext ctx = new InitialContext();
-						Object obj = ctx.lookup(SnmpSharedTableConstant.POLLER_MANAGER_JNDI_NAME);
-						SnmpPollerManager manager = 
-							(SnmpPollerManager)PortableRemoteObject.narrow(obj, SnmpPollerManager.class);
+						Object obj = ctx.lookup(SharedTableConstant.POLLER_MANAGER_JNDI_NAME);
+						PollerManager manager = 
+							(PollerManager)PortableRemoteObject.narrow(obj, PollerManager.class);
 						
 						// ポーリングを開始する
 						try {
 							// ポーラを取得
-							SnmpPoller poller = manager.getPoller(monitorTypeId, facilityId);
+							PollingController poller = manager.getPoller(monitorTypeId, facilityId);
 							// ない場合は生成する
 							if(poller == null){
 								poller = manager.createPoller(monitorTypeId, facilityId, true, monitorTypeId, facilityId);
 							}
-							poller.startPolling(monitorId, interval, SnmpSharedTableConstant.PROCESS_OIDS);
+							
+							// リポジトリ,DBから設定情報を取得する(プラットフォームID, サブプラットフォームID, 収集方法など)
+							PollingDataManager dataManager = new PollingDataManager(facilityId);
+							String collectMethod = dataManager.getCollectMethod();
+							
+							// 取得したプラットフォームにおいて、プロセス監視で何が使われているかを取得
+							HashMap<String, List<String>> map = new HashMap<String, List<String>>();
+							map.put(collectMethod, dataManager.getPollingTargets(collectMethod));
+							
+							poller.startPolling(monitorId, interval, map);
 						} catch (NotInitializedException e) {
 							m_log.error(e.getMessage(), e);
 						} catch (DataTableNotFoundException e) {
@@ -156,7 +201,7 @@ public class ModifyPollingSchedule {
 			
 			try{
 				// SNMP収集値の共有テーブルをルックアップ
-		        SharedTable sst = SnmpProcConnectionManager.getSnmpSharedTable();
+		        SharedTable sst = PollingProcConnectionManager.getSharedTable();
 				
 				// ファシリティIDの配下全ての一覧を取得
 				RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
@@ -176,18 +221,18 @@ public class ModifyPollingSchedule {
 					
 					// ポーラを生成する
 					InitialContext ctx = new InitialContext();
-					Object obj = ctx.lookup(SnmpSharedTableConstant.POLLER_MANAGER_JNDI_NAME);
-					SnmpPollerManager manager = 
-						(SnmpPollerManager)PortableRemoteObject.narrow(obj, SnmpPollerManager.class);
+					Object obj = ctx.lookup(SharedTableConstant.POLLER_MANAGER_JNDI_NAME);
+					PollerManager manager = 
+						(PollerManager)PortableRemoteObject.narrow(obj, PollerManager.class);
 					
 					// ポーリングを停止する
-					SnmpPoller poller = manager.getPoller(monitorTypeId, facilityId);
+					PollingController poller = manager.getPoller(monitorTypeId, facilityId);
 					if(poller != null){
 						poller.stopPolling(monitorId);
 					}
 					
 					// テーブルから参照登録を削除する
-					obj = ctx.lookup(SnmpSharedTableConstant.SHARED_TABLE_JNDI_NAME);
+					obj = ctx.lookup(SharedTableConstant.SHARED_TABLE_JNDI_NAME);
 					SharedTable sharedTable = 
 						(SharedTable)PortableRemoteObject.narrow(obj, SharedTable.class);
 					
