@@ -33,9 +33,11 @@ public class ProcessProperties {
 
 	private static final String START_SECOND = "10";
 	private static final String VALID_SECOND = "15";
+	private static final String DETAILED_DISPLAY = "false";
     
 	private static final String START_SECOND_KEY = "monitor.process.start.second";
 	private static final String VALID_SECOND_KEY = "monitor.process.valid.second";
+	private static final String DETAILED_DISPLAY_KEY = "monitor.process.details.display";
 	
 	private static ProcessProperties m_instance = null;
 	
@@ -43,6 +45,8 @@ public class ProcessProperties {
 	private int m_startSecond;
 	/** SNMPポーラー収集許容時間（秒） */
 	private int m_validSecond;
+	/** オリジナルメッセージにプロセスを表示させるかのフラグ */
+	private boolean m_detailedDisplay;
 	
 	/**
 	 * このオブジェクトを取得します。
@@ -89,10 +93,16 @@ public class ProcessProperties {
 			
 			String startSecond = properties.getProperty(START_SECOND_KEY, START_SECOND);
 			String validSecond = properties.getProperty(VALID_SECOND_KEY, VALID_SECOND);
+			String detailedDisplay = properties.getProperty(DETAILED_DISPLAY_KEY, DETAILED_DISPLAY);
 			
-			m_startSecond = new Integer(startSecond).intValue();
-			m_validSecond = new Integer(validSecond).intValue();
+			if(startSecond != null && !startSecond.equals(""))
+				m_startSecond = new Integer(startSecond).intValue();
 			
+			if(validSecond != null && !validSecond.equals(""))
+				m_validSecond = new Integer(validSecond).intValue();
+			
+			if(detailedDisplay != null && !detailedDisplay.equals(""))
+				m_detailedDisplay = new Boolean(detailedDisplay).booleanValue();
 			
 		} catch (Exception e) {
 			m_log.error("setValue(): " + e.getMessage());
@@ -112,4 +122,11 @@ public class ProcessProperties {
 	public int getValidSecond() {
 		return m_validSecond;
 	}
+	
+	/**
+	 * @return m_detailsDisplay を戻します。
+	 */
+	public boolean isDetailedDisplay() {
+		return m_detailedDisplay;
+	}
 }
