@@ -31,7 +31,6 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
 import com.clustercontrol.accesscontrol.util.TimeKeeper;
 import com.clustercontrol.accesscontrol.util.TimeKeeperService;
-import com.clustercontrol.repository.bean.DeviceInfoAttributeConstant;
 import com.clustercontrol.repository.bean.FileSystemInfoAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoBean;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoPK;
@@ -101,7 +100,10 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				if(attrs.get(FileSystemInfoAttributeConstant.DESCRIPTION) != null){
 					ejb.setDescription((String)attrs.get(FileSystemInfoAttributeConstant.DESCRIPTION).get(0));
 				}
-				
+				//ccDisplayName取得
+				if(attrs.get(FileSystemInfoAttributeConstant.DISPLAYNAME) != null){
+					ejb.setDisplayName((String)attrs.get(FileSystemInfoAttributeConstant.DISPLAYNAME).get(0));
+				}
 				//dnからファシリティIDを抽出する
 				//dnは下記の内容となるため、初めに出現する","以前と最後に出現する","以降を削除したあと
 				//"ccFacilityId="を削除する。
@@ -235,6 +237,16 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				else if(attrs.get(FileSystemInfoAttributeConstant.FILESYSTEMTYPE) != null && ejb.getFileSystemType() != null){
 					replaceAttrs.put(FileSystemInfoAttributeConstant.FILESYSTEMTYPE, ejb.getFileSystemType());
 				}
+				//ccDisplayName設定
+				if(attrs.get(FileSystemInfoAttributeConstant.DISPLAYNAME) == null && ejb.getDisplayName() != null){
+					addAttrs.put(FileSystemInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
+				else if(attrs.get(FileSystemInfoAttributeConstant.DISPLAYNAME) != null && ejb.getDisplayName() == null){
+					removeAttrs.put(FileSystemInfoAttributeConstant.DISPLAYNAME, null);
+				}
+				else if(attrs.get(FileSystemInfoAttributeConstant.DISPLAYNAME) != null && ejb.getDisplayName() != null){
+					replaceAttrs.put(FileSystemInfoAttributeConstant.DISPLAYNAME, ejb.getDisplayName());
+				}
 				//属性を変更する（追加）
 				ctx.modifyAttributes(
 						ejb.getDn(), 
@@ -400,25 +412,7 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-				
-				// 各種属性値をセットする
-				
-				if (ejb.getSnmpOID() != null) {
-					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMSNMPOID, ejb.getSnmpOID());
-				}
-				
-				if (ejb.getFileSystemMountPoint() != null) {
-					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMMOUNTPOINT, ejb.getFileSystemMountPoint());
-				}
-				
-				if (ejb.getFileSystemType() != null) {
-					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMTYPE, ejb.getFileSystemType());
-				}
-				
-				if (ejb.getDescription() != null) {
-					attrs.put(FileSystemInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
-				}
-				
+	
 				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
 				timer = TimeKeeperService.start();
 				
@@ -919,5 +913,6 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 	    ejb.setDn(null);
 	    ejb.setFacilityId(null);
 	    ejb.setSnmpOID(null);
+	    ejb.setDisplayName(null);
 	}
 }
