@@ -17,10 +17,12 @@ package com.clustercontrol.repository.ejb.session;
 
 import java.net.UnknownHostException;
 import java.rmi.RemoteException;
+import java.rmi.dgc.VMID;
 import java.security.Principal;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Hashtable;
+import java.util.Iterator;
 import java.util.Locale;
 
 import javax.ejb.CreateException;
@@ -42,6 +44,8 @@ import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.bean.NodeListTabelDefine;
 import com.clustercontrol.repository.bean.NodeScopeTabelDefine;
 import com.clustercontrol.repository.bean.ScopeListTableDefine;
+import com.clustercontrol.repository.bean.TopicConstant;
+import com.clustercontrol.repository.ejb.entity.FacilityData;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.repository.factory.DeleteFacility;
@@ -51,6 +55,7 @@ import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.repository.factory.ScopeProperty;
 import com.clustercontrol.repository.factory.SearchNodeBySNMP;
 import com.clustercontrol.repository.factory.SelectFacility;
+import com.clustercontrol.repository.util.SendTopic;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 
@@ -134,7 +139,52 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		FacilityTreeItem item = null;
 		try {
 			SelectFacility select = new SelectFacility();
-			item = select.getFacilityTree(locale);
+			item = select.getFacilityTree(locale, null);
+		} catch (FinderException e) {
+			m_log.debug("RepositoryControllerBean.getFacilityTree() -> " + e.getMessage());
+			throw e;
+		} catch (NamingException e) {
+			throw e;
+		}
+
+		return item;
+	}
+	
+	/**
+	 * ファシリティツリー（スコープツリー）取得を取得します。(有効なノードのみ)
+	 * <BR>
+	 * 取得したファシリティツリーには割り当てられたノードを含みます。<BR>
+	 * このメソッドはクライアントの画面情報を作成するために
+	 * 呼び出されます。クライアントのロケールを引数をして必要とします。<BR>
+	 * （最上位のスコープという表記をscopeをいう表記を切り替えるため。）
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 * 
+	 * @jboss.method-attributes
+	 *     read-only="true"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 * 
+	 * @version 1.0.0
+	 * @since 1.0.0
+	 * 
+	 * @param locale クライアントのロケール
+	 * @return FacilityTreeItemの階層オブジェクト
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
+	public FacilityTreeItem getExecTargetFacilityTree(Locale locale) throws FinderException, NamingException {
+
+		//ファシリティツリー(ノード含む)を取得
+		FacilityTreeItem item = null;
+		try {
+			SelectFacility select = new SelectFacility();
+			item = select.getFacilityTree(locale, Boolean.TRUE);
 		} catch (FinderException e) {
 			m_log.debug("RepositoryControllerBean.getFacilityTree() -> " + e.getMessage());
 			throw e;
@@ -954,7 +1004,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
      *     role-name="RepositoryWrite"
      *     method-intf="Remote"
 	 * 
-	 * @version 1.0.0
+	 * @version 3.1.0
 	 * @since 1.0.0
 	 * 
 	 * @param parentFacilityId
@@ -968,6 +1018,63 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		modify.addScope(parentFacilityId, property);
 	}
 	
+	/**
+	 * スコープを新規に追加します(表示順指定)。<BR>
+	 * 
+	 * parentFacilityIdで指定されるスコープの下にpropertyで指定されるスコープを
+	 * 追加します。<BR>
+	 * 引数propertyには、"ファシリティID"、"ファシリティ名"、"説明"（任意）を含める必要があります。
+	 * 
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 * 
+	 * @version 3.1.0
+	 * @since 1.0.0
+	 * 
+	 * @param parentFacilityId
+	 * @param property
+	 * @param sortOrder
+	 * @throws CreateException
+	 * @throws NamingException
+	 * @throws RemoveException
+	 */
+	public void addScope(String parentFacilityId, Property property, int sortOrder) throws RemoveException, CreateException, NamingException {
+		addScope(parentFacilityId,property,sortOrder,true);
+	}
+	
+	/**
+	 * スコープを新規に追加します(表示順指定、リポジトリ更新TOPIC未送信選択可能)。<BR>
+	 * 
+	 * parentFacilityIdで指定されるスコープの下にpropertyで指定されるスコープを
+	 * 追加します。<BR>
+	 * 引数propertyには、"ファシリティID"、"ファシリティ名"、"説明"（任意）を含める必要があります。
+	 * 
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 * 
+	 * @version 3.1.0
+	 * @since 1.0.0
+	 * 
+	 * @param parentFacilityId
+	 * @param property
+	 * @param sortOrder
+	 * @throws CreateException
+	 * @throws NamingException
+	 * @throws RemoveException
+	 */
+	public void addScope(String parentFacilityId, Property property, int sortOrder, boolean sendFlg) throws RemoveException, CreateException, NamingException {
+		ModifyFacility modify = new ModifyFacility();
+		modify.addScope(parentFacilityId, property,sortOrder,sendFlg);
+	}
+	
 	/**
 	 * スコープの情報を変更します。<BR>
 	 * 
@@ -1015,7 +1122,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
      *     role-name="RepositoryWrite"
      *     method-intf="Remote"
 	 * 
-	 * @version 2.0.0
+	 * @version 3.1.0
 	 * @since 1.0.0
 	 * 
 	 * @param property 追加するノード情報のプロパティ
@@ -1023,12 +1130,36 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws CreateException
 	 */
 	public void addNode(Property property) throws NamingException, CreateException, FinderException {
+		addNode(property,true);
+	}
+	
+	/**
+	 * ノードを新規に追加します。（リポジトリ更新TOPIC未送信選択可能）<BR>
+	 * 
+	 * 引数のpropertyにはノードのプロパティが含まれている必要があります。<BR>
+	 * com.clustercontrol.repository.factory.NodePropertyを参照してください。<BR>
+	 * またこのメソッドで組み込みスコープである"登録済みノード"スコープにも
+	 * 割り当てが行われます。
+	 * 
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 * 
+	 * @version 3.1.0
+	 * @since 1.0.0
+	 * 
+	 * @param property 追加するノード情報のプロパティ
+	 * @throws NamingException
+	 * @throws CreateException
+	 */
+	public void addNode(Property property, boolean sendFlg) throws NamingException, CreateException, FinderException {
  		Principal pri = m_context.getCallerPrincipal();
- 		
- 		this.checkFacilityInfo(property);
 			
 		ModifyFacility modify = new ModifyFacility();
-		modify.addNode(property, pri.getName()); //pri.getName()はメソッドの実行ユーザ
+		modify.addNode(property, pri.getName(), sendFlg); //pri.getName()はメソッドの実行ユーザ
 		
 		//ノード追加されると必ず"登録済みノード"スコープに登録される
 		//ファシリティID取得
@@ -1037,7 +1168,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		facilityId[0] = (String)values.get(0);
 		
 		//登録済みノードとしてスコープに割り当てる
-		modify.assignNodeScope(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, facilityId);
+		modify.assignNodeScope(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, facilityId, sendFlg);
 
 	}
 	
@@ -1066,8 +1197,6 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		try {
 			Principal pri = m_context.getCallerPrincipal();
 			
-			this.checkFacilityInfo(property);
-			
 			ModifyFacility modify = new ModifyFacility();
 			modify.modifyNode(property, pri.getName());
 			
@@ -1108,8 +1237,6 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		try {
 			Principal pri = m_context.getCallerPrincipal();
 			
-	 		this.checkFacilityInfo(property);
-			
 			ModifyFacility modify = new ModifyFacility();
 			modify.modifyAllNode(property, parentFacilityId, pri.getName());
 		} catch (NamingException e) {
@@ -1197,6 +1324,40 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		}
 	}
 	
+	/**
+	 * スコープへのノードの割り当てを行います。（リポジトリ更新TOPIC未送信選択可能）<BR>
+	 * 
+	 * parentFacilityIdで指定されるスコープにfacilityIdsで指定されるノード群を
+	 * 割り当てます。
+	 * 
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 * 
+	 * @version 3.1.0
+	 * @since 1.0.0
+	 * 
+	 * @param parentFacilityId　ノードを割り当てるスコープ
+	 * @param facilityIds 割り当てさせるノード(群)
+	 * @throws NamingException
+	 * @throws CreateException
+	 */
+	public void assignNodeScope(String parentFacilityId, String[] facilityIds, boolean sendFlg) throws NamingException, CreateException, FinderException {
+		try {
+			ModifyFacility modify = new ModifyFacility();
+			modify.assignNodeScope(parentFacilityId, facilityIds, sendFlg);
+		} catch (NamingException e) {
+			throw e;
+		} catch (CreateException e) {
+			throw e;
+		} catch (FinderException e) {
+			throw e;
+		}
+	}
+	
 	/**
 	 * スコープへのノードの割り当てを行います。<BR>
 	 * 
@@ -1210,7 +1371,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
      *     role-name="RepositoryWrite"
      *     method-intf="Remote"
 	 * 
-	 * @version 1.0.0
+	 * @version 3.1.0
 	 * @since 1.0.0
 	 * 
 	 * @param parentFacilityId　ノードを割り当てるスコープ
@@ -1219,16 +1380,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws CreateException
 	 */
 	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException, FinderException {
-		try {
-			ModifyFacility modify = new ModifyFacility();
-			modify.assignNodeScope(parentFacilityId, facilityIds);
-		} catch (NamingException e) {
-			throw e;
-		} catch (CreateException e) {
-			throw e;
-		} catch (FinderException e) {
-			throw e;
-		}
+		assignNodeScope(parentFacilityId,facilityIds,true);
 	}
 	
 	/**
@@ -1242,7 +1394,7 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
      *     role-name="RepositoryWrite"
      *     method-intf="Remote"
 	 * 
-	 * @version 1.0.0
+	 * @version 3.1.0
 	 * @since 1.0.0
 	 * 
 	 * @param parentFacilityId ノードを取り除くスコープ
@@ -1252,9 +1404,34 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 * @throws FinderException
 	 */
 	public void releaseNodeScope(String parentFacilityId, String[] facilityIds) throws FinderException, NamingException, RemoveException {
+		releaseNodeScope(parentFacilityId, facilityIds, true);
+	}
+	
+	
+	/**
+	 * ノードをスコープから削除します。（割り当てを解除します。リポジトリ更新TOPIC未送信選択可能）<BR>
+	 * parentFacilityIdで指定されるスコープからfacilityIdsで指定されるノード群を
+	 * 削除（割り当て解除）します。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 * 
+	 * @version 3.1.0
+	 * @since 1.0.0
+	 * 
+	 * @param parentFacilityId ノードを取り除くスコープ
+	 * @param facilityIds 取り除かれるノード（群）
+	 * @throws RemoveException
+	 * @throws NamingException
+	 * @throws FinderException
+	 */
+	public void releaseNodeScope(String parentFacilityId, String[] facilityIds, boolean sendFlg) throws FinderException, NamingException, RemoveException {
 		try {
 			DeleteFacility delete = new DeleteFacility();
-			delete.releaseNodeScope(parentFacilityId, facilityIds);
+			delete.releaseNodeScope(parentFacilityId, facilityIds,sendFlg);
 		} catch (FinderException e) {
 			m_log.debug("RepositoryControllerBean.releaseNodeScope() -> " + e.getMessage());
 			throw e;
@@ -1528,169 +1705,140 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
              return  SearchNodeBySNMP.searchNode(pollingData,mode,locale);
             
     }
+    
+    /**
+     * ファシリティIDより対象ノードのノードプロパティ情報をDataオブジェクトで取得する。<BR>
+     * 
+     * @ejb.interface-method
+     * 
+     * @ejb.permission
+     * role-name="RepositoryRead"
+     * method-intf="Local"
+     *     
+     * @ejb.transaction
+     *     type="NotSupported"
+     * 
+     * @param facilityId ノードのファシリティID
+     * @return ノードのプロパティ情報一式
+     * @throws NamingException
+     * @throws FinderException
+     * 
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+     */
+    public FacilityData  getNodeFacilityData(String facilityId) throws NamingException, FinderException{
+    	SelectFacility select  = new SelectFacility();
+    	return select.getNodeFacilityData(facilityId);   
+    }
 	
-
+    
 	/**
+	 * 空のノードプロパティを取得します。<BR>
 	 * 
-	 * ノード登録・変更時に入力情報が正しいかチェックするためのメソッド。
-	 * 不正な場合、EJBExceptionをスローする。
+	 * @ejb.interface-method
 	 * 
-	 * チェック内容は、入力必須項目が入力されているかどうか。
-	 * 文字数のチェックはしない。
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
 	 * 
-	 * @param property
-	 * @throws EJBException
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+	 * @param locale クライアントのロケール
+	 * @return ノード情報プロパティ
 	 */
-	private void checkFacilityInfo(Property property) throws EJBException {
-		
-		ArrayList values = null;
-		
-		//ファシリティID取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
-		String facilityId = checkString(values.get(0));
-		if (facilityId == null) {
-			throw new EJBException("facilityId is null");
-		}
-		
-		//ファシリティ名取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_NAME);
-		String facilityName = checkString(values.get(0));
-		if (facilityName == null) {
-			throw new EJBException("facilityId=" + facilityId + " : facilityName is null");
-		}
-		
-		//プラットフォームを取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.PLATFORM_FAMILY_NAME);
-		String platform = checkString(values.get(0));
-		if (platform == null) {
-			throw new EJBException("facilityId=" + facilityId + " : platform is null");
-		}
-		
-		//IPアドレスを取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_VERSION);
-		Object obj = values.get(0);
-	    Integer ipAddressVersion = null; 
-        
-        if(obj.getClass() == Integer.class){
-        	ipAddressVersion = (Integer)obj;
-        }
-		
-        if(ipAddressVersion == null || ipAddressVersion == 4) {
-        	
-    		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V4);
-    		String ip4Address = checkString(values.get(0));
-    		if (ip4Address == null) {
-    			throw new EJBException("facilityId=" + facilityId + " : ip4Address is null");
-    		}
-        	
-        }
-        else if(ipAddressVersion == 6){
-        	
-    		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V6);
-    		String ip6Address = checkString(values.get(0));
-    		if (ip6Address == null) {
-    			throw new EJBException("facilityId=" + facilityId + " : ip6Address is null");
-    		}
-        	
-        }
-        else {
-        	
-        	throw new EJBException("facilityId=" + facilityId + " : ipAddressVersion is incorrect");
-        	
-        }
-        
-		
-		//ノード名を取得
-		values = PropertyUtil.getPropertyValue(property, NodeProperty.NODE_NAME);
-		String nodeName = checkString(values.get(0));
-		if (nodeName == null) {
-			throw new EJBException("facilityId=" + facilityId + " : nodeName is null");
-		}
-		
-		
-		// デバイス情報のバリデーションチェック
-		ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
-		for(int i = 0; i < deviceList.size(); i++){
-		    //デバイスINDEXを取得
-			Property deviceProperty = (Property)deviceList.get(i);
-			
-			//デバイス名を取得
-			String deviceName = checkString(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME).get(0));
-			//デバイスインデックスを取得
-			Integer deviceIndex = checkInteger(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX).get(0));
-			//デバイスタイプを取得
-			String deviceType = checkString(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE).get(0));
-			if ((deviceName == null || deviceName.equals("")) && deviceIndex == null && 
-				(deviceType == null || deviceType.equals(""))) {
-				continue;
-			}
-			if (deviceName == null) {
-				throw new EJBException("facilityId=" + facilityId + " : deviceName is null");
-			}
-			if (deviceIndex == null) {
-				throw new EJBException("facilityId=" + facilityId + ", deviceName=" + deviceName + " : deviceIndex is null");
-			}
-			if (deviceType == null) {
-				throw new EJBException("facilityId=" + facilityId + ", deviceName=" + deviceName + " : deviceType is null");
-			}
-			
-		}
-		
-		// ファイルシステム情報のバリデーションチェック			
-		ArrayList filesystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
-		for(int i = 0; i < filesystemList.size(); i++){
-			
-			Property filesystemProperty = (Property)filesystemList.get(i);
-			
-			//ファイルシステムマウントポイントを取得
-			String mountPoint = checkString(PropertyUtil.getPropertyValue(filesystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT).get(0));
-			//ファイルシステムINDEXを取得
-			Integer filesystemIndex = checkInteger(PropertyUtil.getPropertyValue(filesystemProperty, NodeProperty.FILE_SYSTEM_INDEX).get(0));
-			if ((mountPoint == null || mountPoint.equals("")) && filesystemIndex == null) {
-				continue;
-			}
-			if (mountPoint == null) {
-				throw new EJBException("facilityId=" + facilityId + " : fileSystemMountPoint is null");
-			}
-			if (filesystemIndex == null) {
-				throw new EJBException("facilityId=" + facilityId + ", fileSystemMountPoint=" + mountPoint + " : fileSystemIndex is null");
-			}
-			
-		}
-	}
-	/**
-	 * Integerのインスタンスかチェックし、違っていればnullを返す
-	 * 
-	 * @param value
-	 * @return
-	 */
-    private Integer checkInteger(Object value){
-		if(value instanceof Integer){
-			return (Integer)value;
-		}
-		else{
-			return null;
-		}
+	public Property getNodeProperty(int mode, Locale locale) throws FinderException, NamingException{
+		NodeProperty node = new NodeProperty();
+		return node.getProperty(mode, locale);
 	}
 	
 	/**
-	 * Stringのインスタンスかチェックし、違っていればnullを返す
+	 * 条件のHashMapに該当するノードのファシリティIDのリストを返却する。<BR>
 	 * 
-	 * @param value
-	 * @return
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 * 
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+	 * @return ArrayList<String>
 	 */
-	private String checkString(Object value){
-		if(value instanceof String){
-			if(((String)value).compareTo("") == 0){
-				return null;
-			}
-			else{
-				return (String)value;
-			}
-		}
-		else{
-			return null;
-		}
+	public ArrayList<String> findByCondition(HashMap<String, String> condition) throws FinderException, NamingException{
+		SelectFacility selectFacility = new SelectFacility();
+		return selectFacility.findByCondition(condition);
 	}
 	
+	/**
+	 * 空のスコーププロパティを返却する。<BR>
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 * 
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+	 * @return Property
+	 */
+	public Property getScopeProperty(int mode, Locale locale){
+		ScopeProperty scopeProperty = new ScopeProperty();
+		return scopeProperty.getProperty(mode, locale);
+	}
+	
+	/**
+	 * FacilityDataオブジェクトを設定した詰め替えたノードプロパティを返却する。<BR>
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryRead"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 * 
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+	 * @return Property
+	 */
+	public Property getNodeProperty(FacilityData facilityData, Locale locale) throws CreateException,NamingException,FinderException{
+		SelectFacility select = new SelectFacility();
+		return select.getNodeProperty(facilityData, locale);
+	}
+	
+	/**
+	 * リポジトリ更新のTOPICを送信する。<BR>
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+     *     role-name="RepositoryWrite"
+     *     method-intf="Remote"
+	 *     
+     * @ejb.transaction
+	 *     type="NotSupported"
+	 *     
+	 * @version 3.1.0
+	 * @since 3.1.0
+	 * 
+	 */
+	public void sendRepositoryUpdateTopic(){
+		SendTopic.sendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+	}
 }
\ No newline at end of file
