@@ -1605,15 +1605,15 @@ public class NodeProperty {
 		Object[][] ret = null;
 		
 		try {
-			Collection<VmProtocolMstLocal> vmProtocols = VmProtocolMstUtil.getLocalHome().findAll();
-			Iterator<VmProtocolMstLocal> iterator = vmProtocols.iterator();
+			Collection<String> vmProtocols = VmProtocolMstUtil.getLocalHome().findDistinctProtocol();
+			Iterator<String> iterator = vmProtocols.iterator();
 			
 			ArrayList<String> vmProtocolList = new ArrayList<String>();
 			vmProtocolList.add("");
 			
 			while(iterator.hasNext()) {
-				VmProtocolMstLocal vmProtocol = iterator.next();
-				vmProtocolList.add(vmProtocol.getProtocol());
+				String protocol = iterator.next();
+				vmProtocolList.add(protocol);
 			}
 			
 			ret = new Object[2][vmProtocolList.size()];
