@@ -65,8 +65,6 @@ public class PollingController {
 	private final static int RUNNING = 1;
 	private final static int STOPPED = 2;
 	
-	private Object lock = new Object();
-	
 	private String m_quartzJndiName = "QuartzRAM";
 	private String m_quartzJobName;  // ポーラ名とする
 	private String m_quartzGroupName;  // ポーラグループとする
@@ -332,266 +330,264 @@ public class PollingController {
 	 * ポーリングを実行する
 	 */
 	public void run() {
-		synchronized (lock) {	
-			// デバッグログ出力
-			m_log.debug("run start : " + m_pollerGroup + "  " + m_pollerName);
-		
-			SharedTable sharedTable = null;
-			// 収集値格納用テーブルをルックアップ
-			try {
-				// 共有テーブルをルックアップして取得する
-				sharedTable = lookupSharedTable();
-				if(sharedTable == null){
-					// 書き込み対象テーブルを取得できないため終了する
-					return;
-				}
-			} catch (NamingException e) {
-				m_log.error(e.getMessage(), e);
-			}
-			
-			try {
-				/* ポーリングしても意味のないポーリング対象がないかチェックする */
-
-				/* ポーラが管理している収集名のうち、書き込み対象である共有テーブルでは
-				 * 既に参照対象でなくなっている収集名を特定する */
-				
-				// 共有テーブルで参照される収集名のセットを取得
-				Set<String> retainCollectorNames = 
-					new HashSet<String>(sharedTable.getCollectorNames(m_tableGroup, m_tableName));
-
-				// ポーラで保持している収集名のセットを取得
-				Set<String> pollerCollectorNames = m_pollingConfig.getCollectorNames();
-				
-				// 共通要素を抽出
-				retainCollectorNames.retainAll(pollerCollectorNames);
-				
-				// 削除対象の収集名
-				Set<String> removeCollectoName = 
-					new HashSet<String>(m_pollingConfig.getCollectorNames());
-				removeCollectoName.removeAll(retainCollectorNames);
-				
-				synchronized (modifyLock) {
-					Iterator<String> itr = removeCollectoName.iterator();
-					
-					boolean modifyFlg = false;
-					while(itr.hasNext()){
-						String collectorName = itr.next();
-						// 指定の収集名で、収集間隔、ポーリング対象のリストを削除する
-						modifyFlg = m_pollingConfig.removePollingTargets(collectorName);
-					}
-
-					// 最小収集間隔が変更されている場合はスケジューリング
-					if(modifyFlg){
-						scheduleJob();
-					}
-				}
-			} catch (DataTableNotFoundException e) {
-				m_log.error(e.getMessage(), e);
+		// デバッグログ出力
+		m_log.debug("run start : " + m_pollerGroup + "  " + m_pollerName);
+	
+		SharedTable sharedTable = null;
+		// 収集値格納用テーブルをルックアップ
+		try {
+			// 共有テーブルをルックアップして取得する
+			sharedTable = lookupSharedTable();
+			if(sharedTable == null){
 				// 書き込み対象テーブルを取得できないため終了する
 				return;
 			}
-
-			// 共有テーブルが保持しているデータホルダのうち有効である収集間隔のセットを取得
-			Set<Integer> holderIntervals;
-			try {
-				holderIntervals = sharedTable.getIntervals(m_tableGroup, m_tableName);
-			} catch (DataTableNotFoundException e) {
-				m_log.error(e.getMessage(), e);
-				// 書き込み対象テーブルを取得できないため終了する
-				return;
-			}
-		
-			// 更新すべきテーブルがない場合は処理終了
-			if(holderIntervals.size() <= 0){
-				return;
-			}		
-		
-			// 現在時刻を取得
-			long now = System.currentTimeMillis();
-
-			// 今のタイミングで更新すべきテーブルを特定するため、
-			// 更新の必要のある収集間隔のリストを取得する
-			List<Integer> intervals = m_pollingConfig.getCurrentRefreshIntervals(now);
-		
-			ArrayList<Integer> tmpList = new ArrayList<Integer>(intervals);
-		
-			// 全エンティティ内を調べるループをまわすためテンポラリのリストを作成
-			Iterator<Integer> itr = tmpList.iterator();
-			while(itr.hasNext()){
-				int interval = itr.next();
-				// 存在しない場合は収集対象から削除する
-				if(!holderIntervals.contains(interval)){
-					m_log.debug("Remove : " + interval);
-					intervals.remove(new Integer(interval));
-				}
-			}
-		
-			// 更新すべきテーブルがない場合は処理終了
-			if(intervals.size() <= 0){
-				return;
-			}
-		
-			// ポーリング対象の中から今のタイミングで収集すべきものを抽出する
-			HashMap<String, List<String>> pollingTargetMap = m_pollingConfig.getCurrentTargetMap(now);
-		
-			m_log.debug("run() pollingTargetMap : " + pollingTargetMap);
-			// 収集すべきポーリング対象がない場合は処理終了
-			if(pollingTargetMap.size() <= 0){
-				m_log.debug("polling targets are nothing.");
-				return;
-			}
-			
-			PollerConfig pollerConfig = m_pollingConfig.getPollerConfig();
-			
-			
-			// ポーリングを行い値を収集
-			DataTable dataTable = new DataTable();
-			
-			// *****************************
-			// SNMPのpollerの設定
-			// *****************************
-			if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP) != null) {
-				SnmpPollerConfig snmpConfig = pollerConfig.getSnmpConfig();
-				SnmpPollerImpl poller = new SnmpPollerImpl();
-				poller.polling(
-						pollerConfig.getAddress(), 
-						snmpConfig.getPort(),
-						snmpConfig.getVersion(),
-						snmpConfig.getComunity(),
-						snmpConfig.getRetries(),
-						snmpConfig.getTimeout(),
-						pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP), 
-						m_pollingConfig.isIndexCheckFlg(),
-						dataTable);
-			}
-			
-			// *****************************
-			// WBEMのpollerの設定
-			// *****************************
-			if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM) != null) {
-				WbemPollerConfig wbemConfig = pollerConfig.getWbemConfig();
-				WbemPollerImpl poller = new WbemPollerImpl();
-				poller.polling(
-						pollerConfig.getAddress(), 
-						wbemConfig.getPort(),
-						wbemConfig.getProtocol(),
-						wbemConfig.getUserName(),
-						wbemConfig.getPassword(),
-						wbemConfig.getNameSpace(),
-						wbemConfig.getRetries(),
-						wbemConfig.getTimeout(),
-						pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM),
-						dataTable);
-			}
-			
-			// *****************************
-			// 仮想化のpollerの設定
-			// *****************************
-			Iterator<String> pollerProtocolItr = pollingTargetMap.keySet().iterator();
-			while (pollerProtocolItr.hasNext()) {
-				String pollerProtocol = pollerProtocolItr.next();
-				m_log.debug("pollerProtocol : " + pollerProtocol);
-				if (pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_SNMP) ||
-						pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_WBEM)) {
-					continue;
-				}
-				VmPollerConfig vmConfig = pollerConfig.getVmConfig();
-				VmMethodMstLocal local = null;
-				try {
-					local = VmMethodMstUtil.getLocalHome().findByPrimaryKey(new VmMethodMstPK(
-						pollerProtocol, VmMethodTypeConstant.POLLERIMPL));
-				} catch (FinderException e) {
-					e.printStackTrace();
-				} catch (NamingException e) {
-					e.printStackTrace();
-				} 
-				if(local == null){
-					m_log.warn(pollerProtocol + "の実行クラスが内部DBに登録されていません。(" +
-							VmMethodTypeConstant.POLLERIMPL +
-							")");
-					continue;
-				}
-				
-				// pollerProtocolの実行クラス名をcc_vm_solution_mstから取得。
-				// 存在していない場合、中止。
-				String className = local.getClassName();
-				m_log.debug("action() : className = " + className);
-				if(className == null) {
-					m_log.warn(pollerProtocol + "の実行クラスが内部DBに登録されていません。。");
-					continue;
-				}
-				
-				// コンストラクタの生成
-				// 失敗したら、中止。
-				Constructor pollerConstructor = null;
-				try {
-					pollerConstructor = Class.forName(className).getConstructor();
-				} catch (SecurityException e) {
-					e.printStackTrace();
-				} catch (NoSuchMethodException e) {
-					e.printStackTrace();
-				} catch (ClassNotFoundException e) {
-					m_log.warn(className + " is not poller class");
-					continue;
-				}
-				if (pollerConstructor == null) {
-					m_log.warn("action() : pollerConstructor is null");
-					continue;
-				}
-					
-				// ポーラーの取得。
-				// 取得できたら、ポーリング実行。
-				VmPollerImplInterface poller = null;
-				try {
-					poller = (VmPollerImplInterface) pollerConstructor.newInstance();
-				} catch (Exception e) {
-					e.printStackTrace();
-				}
-				if (poller == null) {
-					m_log.warn("action() : poller is null");
-					continue;
-				}
-						
-				poller.init(pollerProtocol);
-				poller.polling(
-						pollerConfig.getAddress(),
-						vmConfig.getVmNodeType(),
-						vmConfig.getVmManagementNodeIp(),
-						vmConfig.getVmName(),
-						vmConfig.getVmUser(),
-						vmConfig.getVmUserPassword(),
-						vmConfig.getVmProtocol(),
-						pollingTargetMap.get(pollerProtocol), dataTable);
-			}
-			
-			m_log.debug("dataTable" + dataTable);
-			
-			// 収集値を共有テーブルに格納する
-			itr = intervals.iterator();			
-			while(itr.hasNext()){
-				int interval = itr.next();
-				
-				// 新規収集した情報をテーブルの先頭に挿入する
-				m_log.debug("insert " + m_tableGroup + ", "
-						+ m_tableName + ", " + interval);
-				try {
-					// テーブルホルダに収集値を挿入する
-					// IPアドレスを識別キーとすることで、ファシリティで定義されているIPアドレスが変更になった場合に
-					// 変更前と変更後の収集値が同じテーブルホルダに格納されることを防ぐ
-					sharedTable.insertDataTable(
-							m_tableGroup,
-							m_tableName, 
-							interval, 
-							dataTable,
-							pollerConfig.getAddress().toString());
-				} catch (DataTableNotFoundException e) {
-					m_log.error(e.getMessage(), e);
-				}
-			}
-		
-			// デバッグログ出力
-			m_log.debug("run end   : " + m_pollerGroup + "  " + m_pollerName);
+		} catch (NamingException e) {
+			m_log.error(e.getMessage(), e);
 		}
+		
+		try {
+			/* ポーリングしても意味のないポーリング対象がないかチェックする */
+
+			/* ポーラが管理している収集名のうち、書き込み対象である共有テーブルでは
+			 * 既に参照対象でなくなっている収集名を特定する */
+			
+			// 共有テーブルで参照される収集名のセットを取得
+			Set<String> retainCollectorNames = 
+				new HashSet<String>(sharedTable.getCollectorNames(m_tableGroup, m_tableName));
+
+			// ポーラで保持している収集名のセットを取得
+			Set<String> pollerCollectorNames = m_pollingConfig.getCollectorNames();
+			
+			// 共通要素を抽出
+			retainCollectorNames.retainAll(pollerCollectorNames);
+			
+			// 削除対象の収集名
+			Set<String> removeCollectoName = 
+				new HashSet<String>(m_pollingConfig.getCollectorNames());
+			removeCollectoName.removeAll(retainCollectorNames);
+			
+			synchronized (modifyLock) {
+				Iterator<String> itr = removeCollectoName.iterator();
+				
+				boolean modifyFlg = false;
+				while(itr.hasNext()){
+					String collectorName = itr.next();
+					// 指定の収集名で、収集間隔、ポーリング対象のリストを削除する
+					modifyFlg = m_pollingConfig.removePollingTargets(collectorName);
+				}
+
+				// 最小収集間隔が変更されている場合はスケジューリング
+				if(modifyFlg){
+					scheduleJob();
+				}
+			}
+		} catch (DataTableNotFoundException e) {
+			m_log.error(e.getMessage(), e);
+			// 書き込み対象テーブルを取得できないため終了する
+			return;
+		}
+
+		// 共有テーブルが保持しているデータホルダのうち有効である収集間隔のセットを取得
+		Set<Integer> holderIntervals;
+		try {
+			holderIntervals = sharedTable.getIntervals(m_tableGroup, m_tableName);
+		} catch (DataTableNotFoundException e) {
+			m_log.error(e.getMessage(), e);
+			// 書き込み対象テーブルを取得できないため終了する
+			return;
+		}
+	
+		// 更新すべきテーブルがない場合は処理終了
+		if(holderIntervals.size() <= 0){
+			return;
+		}		
+	
+		// 現在時刻を取得
+		long now = System.currentTimeMillis();
+
+		// 今のタイミングで更新すべきテーブルを特定するため、
+		// 更新の必要のある収集間隔のリストを取得する
+		List<Integer> intervals = m_pollingConfig.getCurrentRefreshIntervals(now);
+	
+		ArrayList<Integer> tmpList = new ArrayList<Integer>(intervals);
+	
+		// 全エンティティ内を調べるループをまわすためテンポラリのリストを作成
+		Iterator<Integer> itr = tmpList.iterator();
+		while(itr.hasNext()){
+			int interval = itr.next();
+			// 存在しない場合は収集対象から削除する
+			if(!holderIntervals.contains(interval)){
+				m_log.debug("Remove : " + interval);
+				intervals.remove(new Integer(interval));
+			}
+		}
+	
+		// 更新すべきテーブルがない場合は処理終了
+		if(intervals.size() <= 0){
+			return;
+		}
+	
+		// ポーリング対象の中から今のタイミングで収集すべきものを抽出する
+		HashMap<String, List<String>> pollingTargetMap = m_pollingConfig.getCurrentTargetMap(now);
+	
+		m_log.debug("run() pollingTargetMap : " + pollingTargetMap);
+		// 収集すべきポーリング対象がない場合は処理終了
+		if(pollingTargetMap.size() <= 0){
+			m_log.debug("polling targets are nothing.");
+			return;
+		}
+		
+		PollerConfig pollerConfig = m_pollingConfig.getPollerConfig();
+		
+		
+		// ポーリングを行い値を収集
+		DataTable dataTable = new DataTable();
+		
+		// *****************************
+		// SNMPのpollerの設定
+		// *****************************
+		if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP) != null) {
+			SnmpPollerConfig snmpConfig = pollerConfig.getSnmpConfig();
+			SnmpPollerImpl poller = new SnmpPollerImpl();
+			poller.polling(
+					pollerConfig.getAddress(), 
+					snmpConfig.getPort(),
+					snmpConfig.getVersion(),
+					snmpConfig.getComunity(),
+					snmpConfig.getRetries(),
+					snmpConfig.getTimeout(),
+					pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_SNMP), 
+					m_pollingConfig.isIndexCheckFlg(),
+					dataTable);
+		}
+		
+		// *****************************
+		// WBEMのpollerの設定
+		// *****************************
+		if(pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM) != null) {
+			WbemPollerConfig wbemConfig = pollerConfig.getWbemConfig();
+			WbemPollerImpl poller = new WbemPollerImpl();
+			poller.polling(
+					pollerConfig.getAddress(), 
+					wbemConfig.getPort(),
+					wbemConfig.getProtocol(),
+					wbemConfig.getUserName(),
+					wbemConfig.getPassword(),
+					wbemConfig.getNameSpace(),
+					wbemConfig.getRetries(),
+					wbemConfig.getTimeout(),
+					pollingTargetMap.get(PollerProtocolConstant.PROTOCOL_WBEM),
+					dataTable);
+		}
+		
+		// *****************************
+		// 仮想化のpollerの設定
+		// *****************************
+		Iterator<String> pollerProtocolItr = pollingTargetMap.keySet().iterator();
+		while (pollerProtocolItr.hasNext()) {
+			String pollerProtocol = pollerProtocolItr.next();
+			m_log.debug("pollerProtocol : " + pollerProtocol);
+			if (pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_SNMP) ||
+					pollerProtocol.equals(PollerProtocolConstant.PROTOCOL_WBEM)) {
+				continue;
+			}
+			VmPollerConfig vmConfig = pollerConfig.getVmConfig();
+			VmMethodMstLocal local = null;
+			try {
+				local = VmMethodMstUtil.getLocalHome().findByPrimaryKey(new VmMethodMstPK(
+					pollerProtocol, VmMethodTypeConstant.POLLERIMPL));
+			} catch (FinderException e) {
+				e.printStackTrace();
+			} catch (NamingException e) {
+				e.printStackTrace();
+			} 
+			if(local == null){
+				m_log.warn(pollerProtocol + "の実行クラスが内部DBに登録されていません。(" +
+						VmMethodTypeConstant.POLLERIMPL +
+						")");
+				continue;
+			}
+			
+			// pollerProtocolの実行クラス名をcc_vm_solution_mstから取得。
+			// 存在していない場合、中止。
+			String className = local.getClassName();
+			m_log.debug("action() : className = " + className);
+			if(className == null) {
+				m_log.warn(pollerProtocol + "の実行クラスが内部DBに登録されていません。。");
+				continue;
+			}
+			
+			// コンストラクタの生成
+			// 失敗したら、中止。
+			Constructor pollerConstructor = null;
+			try {
+				pollerConstructor = Class.forName(className).getConstructor();
+			} catch (SecurityException e) {
+				e.printStackTrace();
+			} catch (NoSuchMethodException e) {
+				e.printStackTrace();
+			} catch (ClassNotFoundException e) {
+				m_log.warn(className + " is not poller class");
+				continue;
+			}
+			if (pollerConstructor == null) {
+				m_log.warn("action() : pollerConstructor is null");
+				continue;
+			}
+				
+			// ポーラーの取得。
+			// 取得できたら、ポーリング実行。
+			VmPollerImplInterface poller = null;
+			try {
+				poller = (VmPollerImplInterface) pollerConstructor.newInstance();
+			} catch (Exception e) {
+				e.printStackTrace();
+			}
+			if (poller == null) {
+				m_log.warn("action() : poller is null");
+				continue;
+			}
+					
+			poller.init(pollerProtocol);
+			poller.polling(
+					pollerConfig.getAddress(),
+					vmConfig.getVmNodeType(),
+					vmConfig.getVmManagementNodeIp(),
+					vmConfig.getVmName(),
+					vmConfig.getVmUser(),
+					vmConfig.getVmUserPassword(),
+					vmConfig.getVmProtocol(),
+					pollingTargetMap.get(pollerProtocol), dataTable);
+		}
+		
+		m_log.debug("dataTable" + dataTable);
+		
+		// 収集値を共有テーブルに格納する
+		itr = intervals.iterator();			
+		while(itr.hasNext()){
+			int interval = itr.next();
+			
+			// 新規収集した情報をテーブルの先頭に挿入する
+			m_log.debug("insert " + m_tableGroup + ", "
+					+ m_tableName + ", " + interval);
+			try {
+				// テーブルホルダに収集値を挿入する
+				// IPアドレスを識別キーとすることで、ファシリティで定義されているIPアドレスが変更になった場合に
+				// 変更前と変更後の収集値が同じテーブルホルダに格納されることを防ぐ
+				sharedTable.insertDataTable(
+						m_tableGroup,
+						m_tableName, 
+						interval, 
+						dataTable,
+						pollerConfig.getAddress().toString());
+			} catch (DataTableNotFoundException e) {
+				m_log.error(e.getMessage(), e);
+			}
+		}
+	
+		// デバッグログ出力
+		m_log.debug("run end   : " + m_pollerGroup + "  " + m_pollerName);
 	}
 
 	/**
