@@ -24,6 +24,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
+import java.util.concurrent.CountDownLatch;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -70,12 +71,6 @@ public class SnmpPollerImpl implements SnmpHandler {
 	// 取得したデータを格納するテーブル（ポーリングの度に更新）
 	private DataTable m_dataTable;
 
-	// メッセージ（ポーリングの度に更新）
-	private String m_message = null;
-
-	// 待機フラグ
-	private boolean m_waitFlg;
-
 	// 収集したOIDの最後のインデックスをチェックするか否かのフラグ（ポーリングの度に更新）
 	private boolean m_indexCheckFlg = false;
 
@@ -103,28 +98,97 @@ public class SnmpPollerImpl implements SnmpHandler {
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
 	private ArrayList<String> m_lastPollingOids;
 
-	// 全体的なポーリングをリトライするか否かのフラグ
-	private boolean m_retryFlg = false;
-
-	// 全体的なポーリングのリトライ回数
-	private final int m_retryCount = 1;
-
-	// エラーコード（ポーリングの度に更新）
-	private int m_errorCode = 0;
-
-	// エラーコード
-	private final int Normal = 0; // 正常に動作いている場合
-	private final int TimeOutError = 1; // 問い合わせがタイムアウトした場合
-	private final int InternalError = 2; // タイムアウト以外のエラー
-
+	/**
+	 * アプリケーションスレッドがポーリング完了を待つためのラッチ。
+	 * アプリケーションからの呼び出し箇所では、joeSNMPに実行を依頼した後、
+	 * このラッチを待つ。このラッチは、「setPollerStatus」関数によって
+	 * 解放される。
+	 */
+	private final CountDownLatch latchPollingEnd = new CountDownLatch(1);
+	
+	enum PollerStatus {
+		/** まだこのポーラーが使用されていない状態<br>
+		 * POLLING/INTERNALにのみ状態遷移する。 */
+		NOUSING,
+		/** ポーリング最中でjoeSNMPのスレッドによりコールバックされる状態<br>
+		 * TIMEOUT/INTERNAL/COMPLETEのいずれかに遷移する */
+		POLLING,
+		/** joeSNMPへの依頼に失敗したか、ポーリング中に何らかのエラーが発生した後の状態<br>
+		 * これ以降結果は格納しない。また、これ以降他のステータスに遷移しない。 */
+		INTERNAL,
+		/** タイムアウトエラーが発生した後の状態<br>
+		 * これ以降結果は格納しない。また、これ以降他のステータスに遷移しない。 */
+		TIMEOUT,
+		/** ポーリングでリトライ回数を使い果たした状態<br>
+		 * これ以降結果は格納しない。また、これ以降他のステータスに遷移しない。 */
+		RETRYOVER,
+		/** エラーが発生せず正常に終了した状態<br>
+		 * これ以降テーブルに操作しない。またこれ以降他のステータスに遷移しない。 */
+		COMPLETE
+	}
+	/**
+	 * ポーラーのステータスを表す。（getter/setterを必ず使ってアクセスすること）
+	 * この変数を読み書きする際には必ずlockModifyStatusのでガードが必要となる
+	 */
+	private PollerStatus pollerStatus = PollerStatus.NOUSING;
+	
+	/**
+	 * ポーラーのステータスを取得する。この関数はスレッドセーフではない。
+	 * 呼び出し側は、「lockModifyStatus」オブジェクトによって同期化処理が必要となる。
+	 * この値を基にして、m_dataTable に触るか否かを決定する場合、必ず
+	 * この関数の呼び出しからm_dataTableに対する処理までを１つのsynchronized
+	 * ブロックにくくらなくてはならない。
+	 */
+	private PollerStatus getPollerStatus() {
+		return pollerStatus;
+	}
+	/**
+	 * このポーラー全体のステータスを変更するメソッド。このメソッドは「lockModifyStatus」
+	 * によってスレッドセーフ性が保障されている。また、このメソッドには副作用がある。
+	 * ステートが変更され、かつ、新しいステートが
+	 * 「INTERNAL/TIMEOUT/RETRYOVER/COMPLETE」
+	 * のいずれかである場合、「latchPollingEnd」ラッチが解放される。
+	 * （ポーラーの終了条件を満たした段階でポーリングの終了を通知するラッチを開放する）
+	 */
+	private void setPollerStatus(PollerStatus newStatus) {
+		synchronized (lockModifyStatus) {
+			// 既にINTERNAL/TIMEOUT/RETRYOVER/COMPLETEに
+			// なっている場合には、状態遷移は行わない
+			switch(pollerStatus) {
+			case INTERNAL:
+			case TIMEOUT:
+			case RETRYOVER:
+			case COMPLETE:
+				return;
+			}
+			
+			pollerStatus = newStatus;
+			
+			// 新規ステータスが INTERNAL/TIMEOUT/RETRYOVER/COMPLETEの
+			// いずれかになるになる場合には、 ポーリング終了待ちのラッチを開放する
+			switch(pollerStatus) {
+			case INTERNAL:
+			case TIMEOUT:
+			case RETRYOVER:
+			case COMPLETE:
+				latchPollingEnd.countDown();
+			}
+		}
+		
+	}
+	
+	/**
+	 * ポーラーのステータスを参照・更新変更する際に取得するロック。statusの
+	 * 読み書き・読んだ結果を基にアクションする際には必ずこのロックを取得する。
+	 */
+	private final Object lockModifyStatus = new Object();
+	
 	// クラス変数の初期化
 	private void init(){
 		m_indexCheckDiffIndexRetryCount = 0;
 		m_indexCheckVarBindSizeRetryCount = 0;
 		m_indexCheckRetryCountTotal = 0;
 		m_indexCheckLastIndexRetryCount = 0;
-		m_errorCode = Normal;
-		m_message = null;
 	}
 
 	/**
@@ -193,7 +257,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 		} catch (SocketException e) {
 			m_log.error("polling() warning  :" + ipAddress.toString()
 					+ " SocketException creating the SNMP session");
-			m_errorCode = InternalError;
+			setPollerStatus(PollerStatus.INTERNAL);
 			return;
 		}
 		session.setDefaultHandler(this);
@@ -237,33 +301,29 @@ public class SnmpPollerImpl implements SnmpHandler {
 				i++;
 			}
 
-			for (int count = 0; count < m_retryCount+1; count++) {
-				synchronized (session) {
-					m_waitFlg = true;
-					session.send(pdu);
-					m_log.debug("polling() : " + m_ipAddress + " send SnmpPduRequest");
+			// ステータスをPOLLING中に変更し、実際にjoeSNMPに処理委譲する
+			setPollerStatus(PollerStatus.POLLING);
+			session.send(pdu);
+			m_log.debug("polling() : " + m_ipAddress + " send SnmpPduRequest");
+			// SNMPの処理が完了（orエラーで失敗）するまで待つ。
+			latchPollingEnd.await();
 
-					if (m_waitFlg) {
-						session.wait();
-					}
-				}
-
-				if(m_retryFlg == false){
-					//　リトライしない
-					break;
-				} else {
-					// 一旦取得した全てのデータを削除してリトライ
-					m_dataTable.clear();
-				}
-			}
 		} catch (InterruptedException e) {
 			m_log.error("polling() warning :" + ipAddress.toString()
 					+ " polling failed at InterruptedException");
-			m_errorCode = InternalError;
+			setPollerStatus(PollerStatus.INTERNAL);
 			return;
 		} finally {
 			try {
 
+				// ポーリングステータスが成功して完了した以外の状態になっている場合、
+				// テーブルに含まれているデータを全て削除する。
+				synchronized (lockModifyStatus) {
+					if (getPollerStatus() != PollerStatus.COMPLETE) {
+						m_dataTable.clear();
+					}
+				}
+				
 				session.close();
 
 			} catch (Exception e) {
@@ -277,13 +337,6 @@ public class SnmpPollerImpl implements SnmpHandler {
 			}
 		}
 
-		// 例外処理(未実装)
-		if (this.m_errorCode == TimeOutError) {
-
-		} else if (this.m_errorCode == InternalError) {
-
-		}
-
 		// リトライ回数が多い場合は出力する
 		if(m_indexCheckRetryCountTotal >= 100){
 			m_log.warn("polling():" + m_ipAddress + 
@@ -312,10 +365,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 			} else {
 				m_log.error("polling() error :" + session.toString()
 						+ " Received non-request pdu");
-				synchronized (session) {
-					m_errorCode = InternalError;
-					session.notify();
-				}
+				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
 
@@ -323,20 +373,14 @@ public class SnmpPollerImpl implements SnmpHandler {
 				m_log.error("polling() error :" + session.toString()
 						+ "  Received non-response command "
 						+ pdu.getCommand());
-				synchronized (session) {
-					m_errorCode = InternalError;
-					session.notify();
-				}
+				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
 
 			if (req.getErrorStatus() != 0) {
 				m_log.error("polling() error :" + session.toString()
 						+ "  Error Status " + req.getErrorStatus());
-				synchronized (session) {
-					m_errorCode = InternalError;
-					session.notify();
-				}
+				setPollerStatus(PollerStatus.INTERNAL);
 				return;
 			}
 
@@ -446,7 +490,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
-							m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							synchronized (lockModifyStatus) {
+								if (getPollerStatus() != PollerStatus.POLLING) {
+									return;
+								}
+								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							}
 							
 							m_log.debug("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) + 
@@ -463,7 +512,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
-							m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							synchronized (lockModifyStatus) {
+								if (getPollerStatus() != PollerStatus.POLLING) {
+									return;
+								}
+								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							}
 							
 							m_log.debug("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) + 
@@ -482,7 +536,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 									", time : " + time +
 									", longValue : " + longValue);
 						} else {
-							m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							synchronized (lockModifyStatus) {
+								if (getPollerStatus() != PollerStatus.POLLING) {
+									return;
+								}
+								m_dataTable.putValue(getEntryKey(oidString), time, longValue);
+							}
 							
 							m_log.debug("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) + 
@@ -498,7 +557,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 									", time : " + time +
 									", longValue : " + var.getValue().toString());
 						} else {
-							m_dataTable.putValue(getEntryKey(oidString), time, var.getValue().toString());
+							synchronized (lockModifyStatus) {
+								if (getPollerStatus() != PollerStatus.POLLING) {
+									return;
+								}
+								m_dataTable.putValue(getEntryKey(oidString), time, var.getValue().toString());
+							}
 							
 							m_log.debug("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) + 
@@ -514,7 +578,12 @@ public class SnmpPollerImpl implements SnmpHandler {
 									", time : " + time +
 									", longValue : " + var.getValue().toString());
 						} else {
-							m_dataTable.putValue(getEntryKey(oidString), time, var.getValue());
+							synchronized (lockModifyStatus) {
+								if (getPollerStatus() != PollerStatus.POLLING) {
+									return;
+								}
+								m_dataTable.putValue(getEntryKey(oidString), time, var.getValue());
+							}
 							
 							m_log.debug("snmpReceivedPdu() dataTable put : " +
 									"entryKey : " + getEntryKey(oidString) + 
@@ -541,18 +610,24 @@ public class SnmpPollerImpl implements SnmpHandler {
 								|| (lastPollingOids.size() == 0))) {
 					// 一時的にArrayListで保持されていた取得値をセットする
 					Iterator<TableEntry> itr = entryBuffer.iterator();
-					while(itr.hasNext()){
-						TableEntry entry = itr.next();
-						
-						// デバッグ
-						if (m_log.isDebugEnabled()) {
-							m_log.debug("set (buffer to table) " + m_ipAddress + ","
-									+ entry.getKey() + "," + time + ","
-									+ entry.getValue().toString() + ", "
-									+ entry.getValue());
+					// ステータスを確認し、ポーリング中以外の状態になっている場合には以降の処理をキャンセルする
+					synchronized (lockModifyStatus) {
+						if (getPollerStatus() != PollerStatus.POLLING) {
+							return;
+						}
+						while(itr.hasNext()){
+							TableEntry entry = itr.next();
+							
+							// デバッグ
+							if (m_log.isDebugEnabled()) {
+								m_log.debug("set (buffer to table) " + m_ipAddress + ","
+										+ entry.getKey() + "," + time + ","
+										+ entry.getValue().toString() + ", "
+										+ entry.getValue());
+							}
+							
+							m_dataTable.putValue(entry);
 						}
-						
-						m_dataTable.putValue(entry);
 					}
 					
 					// リトライ回数をリセット
@@ -638,13 +713,6 @@ public class SnmpPollerImpl implements SnmpHandler {
 									+ "  next VarBind size:" + lastPollingOids.size());
 						}
 
-//						// 格納されたMIB値を削除します。
-//						for(int j=0; j < pdu.getLength(); j++){
-//							String removeOid = pdu.getVarBindAt(j).getName().toString();
-//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-//							m_dataTable.removeValue(removeOid);
-//						}
-						
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
@@ -672,10 +740,11 @@ public class SnmpPollerImpl implements SnmpHandler {
 						} else { // リトライ回数の上限を超えた場合
 							m_log.error("too many retries(index not match). " + m_ipAddress 
 									+ " count:" + m_indexCheckDiffIndexRetryCount);
-							// 収集したデータを全てクリアする
-							m_dataTable.clear();
 							
-							// nxtが空となるためポーリングは継続されない
+							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
+							// 終了を通知する。また、以降の処理は全てキャンセルする
+							setPollerStatus(PollerStatus.RETRYOVER);
+							return;
 						}
 						
 						// リトライ回数をカウントアップ
@@ -689,13 +758,6 @@ public class SnmpPollerImpl implements SnmpHandler {
 									+ m_ipAddress);
 						}
 						
-//						// 格納されたMIB値を削除します。
-//						for(int j=0; j < pdu.getLength(); j++){
-//							String removeOid = pdu.getVarBindAt(j).getName().toString();
-//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-//							m_dataTable.removeValue(removeOid);
-//						}
-
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
@@ -722,10 +784,11 @@ public class SnmpPollerImpl implements SnmpHandler {
 						} else { // リトライ回数の上限を超えた場合
 							m_log.error("too many retries(VarBind size not match). " + m_ipAddress 
 									+ " count:" + m_indexCheckVarBindSizeRetryCount);
-							// 収集したデータを全てクリアする
-							m_dataTable.clear();
 							
-							// nxtが空となるためポーリングは継続されない
+							// ステータスをリトライ回数越えに変更し、ポーリング結果を待つスレッドに
+							// 終了を通知する。また、以降の処理は全てキャンセルする
+							setPollerStatus(PollerStatus.RETRYOVER);
+							return;
 						}
 							
 						// リトライ回数をカウントアップ
@@ -742,25 +805,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 				m_lastPollingOids = lastPollingOids;
 				session.send(nxt, this);
 			} else {
-				// 収集を終了します
-				synchronized (session) {
-					session.notify();
-				}
-				
+				// ステータスを正常完了として、ポーリング完了待ちスレッドに通知する
+				setPollerStatus(PollerStatus.COMPLETE);
 				return;
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
 			m_log.error("InternalError ", e);
 
-			// 収集したデータを全てクリアする
-			m_dataTable.clear();
-			
-			// 収集を終了します
-			synchronized (session) {
-				m_errorCode = InternalError;
-				m_message = e.getMessage();
-				session.notify();
-			}
+			// ステータスをインターナルエラーとして、ポーリング完了待ちスレッドに通知する
+			setPollerStatus(PollerStatus.INTERNAL);
 		}
 	}
 
@@ -774,19 +827,8 @@ public class SnmpPollerImpl implements SnmpHandler {
 		+ m_ipAddress + " OID:" + m_oidText[0];
 		m_log.error("snmpInternalError():" + session.toString() + " " + message);
 
-		synchronized (session) {
-			m_errorCode = InternalError;
-			m_message = message;
-
-			// 既に収集されたものも含めて全て削除する
-			for (int j = 0; j < m_oidText.length; j++) {
-				// 収集中のOID配下のOIDの値をテーブルから削除
-				removeTableValue(m_oidText[j]);
-			}
-
-			m_waitFlg = false;
-			session.notify();
-		}
+		// ステータスをインターナルエラーとし、ポーリング完了待ちスレッドに通知する
+		setPollerStatus(PollerStatus.INTERNAL);
 	}
 
 	/**
@@ -815,53 +857,10 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 		m_log.warn(message);
 
-		synchronized (session) {
-			m_errorCode = TimeOutError;
-			m_message = message;
-
-			// 既に収集されたものも含めて全て削除する
-			for (int j = 0; j < m_oidText.length; j++) {
-				// 収集中のOID配下のOIDの値をテーブルから削除
-				removeTableValue(m_oidText[j]);
-			}
-
-			session.notify();
-		}
+		// ステータスをTIMEOUTとし、ポーリング完了待ちスレッドに通知する
+		setPollerStatus(PollerStatus.TIMEOUT);
 	}
 
-	/**
-	 * 収集指定のOID配下のMIB値を全て削除する
-	 * 
-	 * 例)
-	 * .1.3.6.1.2.1.2.2.1   を対象に収集している場合で
-	 * .1.3.6.1.2.1.2.2.1.3 を収集の際にこのメソッドを呼び出した場合
-	 * .1.3.6.1.2.1.2.2.1   配下のMIB値は全て削除されるため
-	 * 既にテーブルに格納済みの
-	 * .1.3.6.1.2.1.2.2.1.1 のMIB値および .1.3.6.1.2.1.2.2.1.2
-	 * のMIB値を削除する
-	 * 
-	 * @param oidText OID
-	 */
-	private void removeTableValue(String oidText) {
-		// テーブルに格納されているOIDのセットを取得
-		Set<String> oidSet = m_dataTable.keySet();
-
-		String[] fullOids = (String[]) oidSet
-		.toArray(new String[oidSet.size()]);
-
-		for (int i = 0; i < fullOids.length; i++) {
-
-			String fullOid = fullOids[i];
-
-			// もし先頭の部分が一致するならそのツリーの子孫と判定
-			if (fullOid.startsWith(getEntryKey(oidText))) {
-				// テーブルに格納されている値を削除
-				m_dataTable.removeValue(fullOid);
-			}
-		}
-	}
-
-	
 	/**
 	 * DataTableに格納するためのEntryKeyを返すメソッド
 	 * 
