@@ -128,7 +128,17 @@ public class TrapSnmp implements SnmpTrapHandler {
 	public void exec(){
 		
 		try{
-			m_trapSession = new SnmpTrapSession(new TrapSnmp(m_manager));
+			if("".equals(m_manager.getHost()) || m_manager.getHost() != null){
+				try {
+					InetAddress add = InetAddress.getByName(m_manager.getHost());
+					m_trapSession = new SnmpTrapSession(new TrapSnmp(m_manager), m_manager.getPort(), add);
+				} catch (Exception e) {
+					m_log.error(e.getMessage(), e);
+				}
+			} else {	
+				m_trapSession = new SnmpTrapSession(new TrapSnmp(m_manager), m_manager.getPort());
+			}
+				
 			m_log.debug("SNMP Trap Receiver Started");
 			
 		}catch (Exception e){
